(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 12.1' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    138350,       2830]
NotebookOptionsPosition[    127860,       2685]
NotebookOutlinePosition[    128502,       2709]
CellTagsIndexPosition[    128459,       2706]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[StyleBox["Last checked 20 April, 2023",
 CellFrame->True,
 Background->GrayLevel[0.849989]]], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.851321730299733*^9, 3.851321747924562*^9}, 
   3.8513218075505953`*^9, {3.890897811719871*^9, 3.890897826726935*^9}, {
   3.890973965108789*^9, 3.8909739653874283`*^9}},
 TextAlignment->Left,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"e73af808-3ca8-448e-9019-d0da18204481"],

Cell["Chapter 7, Section 7.3", "Section",ExpressionUUID->"68e7a372-2af0-423f-a89d-9014c82b299a"],

Cell[TextData[{
 "We start by defining a function ",
 StyleBox["secular", "Input"],
 " that derives a secular perturbation theory for any number of masses with \
given orbital elements."
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"9719ce43-3705-43bc-b327-9ad9c849b491"],

Cell["\<\
(* 
               ==== Secular perturbation solver ==== 
                       v1.0 February 1993 
                         Carl D. Murray             
*)


secular::usage = \"secular[nbody, m, a, ecc, inc, peri, node, n,
\trp, j2, j4] determines the secular perturbation solution for
\tthe gravitational interaction of nbody bodies with mass ratios
\tm, semi-major axes, a, eccentricities, ecc, inclinations, inc,
\tlongitudes of pericentre, peri, longitudes of ascending node,
\tnode, mean motions, n (in degrees/year) which are orbiting a
\tcentral body of radius, rp with J2 and J4 values, j2 and j4.
\tThe function defines ecalc and icalc which can be used to plot
\tthe time variation of the eccentricity and inclination of
\tany of the bodies.\";

secular[nbody_, m_, a_, ecc_, inc_, peri_, node_, n_, 
        rp_, j2_, j4_] :=
(* 
   Based on the theory given in Dermott & Nicholson, Nature,
   319, 115-120.
   
   nbody : number of bodies
   m     : masses of bodies
   a     : semi-major axes of bodies
   ecc   : eccentricities of bodies
   inc   : inclinations of bodies
   peri  : longitudes of pericentre of bodies
   node  : longitudes of ascending nodes of bodies
   n     : mean motion (in degrees/year) of bodies
   rp    : radius of central object
   j2    : J2 of central object
   j4    : J4 of central object
*)  
Module[{rpa2 = N[(rp/a)^2], rpa4 = N[(rp/a)^4], j22=j2*j2,
        mred = 1+m},
Print[\"Mass ratios :\"];
Print[m];
Print[\" \"];
Print[\"Semi-major axes :\"];
Print[a];
Print[\" \"];
Print[\"Mean motions (degrees/year) :\"];
Print[n];
Print[\" \"];
Print[\"Initial values :\"];
Print[\"==============  \"];
Print[\" \"];
Print[\"Eccentricities :\"];
Print[ecc];
Print[\" \"];
Print[\"Longitudes of pericentre :\"];
Print[peri];
Print[\" \"];
Print[\"Inclinations :\"];
Print[inc];
Print[\" \"];
Print[\"Longitudes of ascending node :\"];
Print[node];
Print[\" \"];
(* 
   Set the initial values of h, k, p, q
*)
hinit = ecc*Sin[N[peri]];
kinit = ecc*Cos[N[peri]];
pinit = N[inc*Sin[node]];
qinit = N[inc*Cos[node]];
(*
   Define the alpha, alphabar functions from the D&N paper
*)
alpha[ j_, k_ ] := a[[k]]/a[[j]] /; k <  j;
alpha[ j_, k_ ] := 0             /; k == j;
alpha[ j_, k_ ] := a[[j]]/a[[k]] /; k >  j;
alphabar[ j_, k_ ] := 1             /; k <  j;
alphabar[ j_, k_ ] := 0             /; k == j;
alphabar[ j_, k_ ] := alpha[ j, k ] /; k >  j;
(*
  Define the Laplace coefficient function using a numerical
  integration
*)
laplace[ s_, jj_, aa_ ] := 
  If[aa != 0,
     NIntegrate[ N[ (1/Pi)*(Cos[jj*x])/((1-2aa*Cos[x]+aa^2)^s) ],
                {x, 0, 2Pi} ],
     0];
(*
  Define the elements of the matrices A and B
*)
A[ j_, k_ ] := -(1/4)*m[[k]]*(n[[j]]/mred[[j]])*
                 alpha[j,k]*alphabar[j,k]*
                 laplace[3/2, 2, alpha[j,k]] /; j != k;
A[ j_, k_ ] := n[[j]]*
               ((3/2)*j2*rpa2[[j]] - (9/8)*j22*rpa4[[j]] -
                (15/4)*j4*rpa4[[j]] +
                ((1/4)/mred[[j]])*
                         Sum[If[l != j,
                            m[[l]]*
                            alpha[j,l]*alphabar[j,l]*
                            laplace[3/2, 1, alpha[j,l]],
                            0],
                          {l,nbody}]) /; j == k;
B[ j_, k_ ] := (1/4)*m[[k]]*(n[[j]]/mred[[j]])*
                 alpha[j,k]*alphabar[j,k]*
                 laplace[3/2, 1, alpha[j,k]] /; j != k;
B[ j_, k_ ] := -n[[j]]*
               ((3/2)*j2*rpa2[[j]] - (27/8)*j22*rpa4[[j]] -
                (15/4)*j4*rpa4[[j]] +
                ((1/4)/mred[[j]])*
                         Sum[If[l != j,
                            m[[l]]*
                            alpha[j,l]*alphabar[j,l]*
                            laplace[3/2,1,alpha[j,l]],
                            0],
                          {l,nbody}]) /; j == k;
(*
  Construct the two matrices
*)
bigA = Array[ A, {nbody,nbody} ];
bigB = Array[ B, {nbody,nbody} ];
Print[\"Matrix A (deg/yr):\"];
Print[MatrixForm[bigA]];
Print[\" \"];
Print[\"Matrix B (deg/yr):\"];
Print[MatrixForm[bigB]];
Print[\" \"];
(*
  Solve the resulting eigensystems
*)
esA = Eigensystem[ bigA ];
esB = Eigensystem[ bigB ];
(*
  Extract the two sets of eigenfrequencies ...
*)
g = esA[[1]];
f = esB[[1]];
Print[\"g eigenfrequencies (deg/yr) :\"];
Print[g];
Print[\" \"];
Print[\"g eigenvectors :\"];
Print[MatrixForm[esA[[2]]]];
Print[\" \"];
Print[\"f eigenfrequencies (deg/yr) :\"];
Print[f];
Print[\" \"];
Print[\"f eigenvectors :\"];
Print[MatrixForm[esB[[2]]]];
Print[\" \"];
Print[\"Initial h values :\"];
Print[hinit];
Print[\" \"];
Print[\"Initial k values :\"];
Print[kinit];
Print[\" \"];
Print[\"Initial p values :\"];
Print[pinit];
Print[\" \"];
Print[\"Initial q values :\"];
Print[qinit];
Print[\" \"];
(*
  ... and the corresponding (unscaled) eigenvectors
*)
ebarji = Transpose[esA[[2]]];
ibarji = Transpose[esB[[2]]];
(*
  Determine the values of Sin[beta] and Sin[gamma] and hence
  the scaling of the eigenvectors
*)
fsbeta = LinearSolve[ebarji, hinit];
fcbeta = LinearSolve[ebarji, kinit];
beta = ArcTan[fcbeta, fsbeta];
Print[\"Beta (deg) :\"];
Print[N[beta/Degree]];
Print[\" \"];
sbeta = Sin[beta];
fsgamma = LinearSolve[ibarji, pinit];
fcgamma = LinearSolve[ibarji, qinit];
gamma = ArcTan[fcgamma, fsgamma];
Print[\"Gamma (deg) :\"];
Print[N[gamma/Degree]];
Print[\" \"];
sgamma = Sin[gamma];
emag = fsbeta/sbeta;
imag = fsgamma/sgamma;
eji = Map[Times[#,emag]&, ebarji];
iji = Map[Times[#,imag]&, ibarji];
gr = N[g Degree];
fr = N[f Degree];
Print[\"Scaled h-k eigenvectors :\"];
Print[MatrixForm[eji]];
Print[\" \"];
Print[\"Scaled p-q eigenvectors :\"];
Print[MatrixForm[iji]];
Print[\" \"];
(*
  Use these values to determine e and I as functions of time
*)
ejcalc[j_, t_] := 
  Sqrt[(Plus @@ (eji[[j]]*Sin[gr*t+beta]))^2 + 
       (Plus @@ (eji[[j]]*Cos[gr*t+beta]))^2];
ijcalc[j_, t_] := 
  N[
   Sqrt[(Plus @@ (iji[[j]]*Sin[fr*t+gamma]))^2 + 
        (Plus @@ (iji[[j]]*Cos[fr*t+gamma]))^2]]
];\
\>", "Input",
 AspectRatioFixed->True,
 CellLabel->"In[1]:=",ExpressionUUID->"ff4590b1-a226-44e0-963f-eb797962fbce"],

Cell[TextData[{
 "Now apply the function ",
 StyleBox["secular", "Input"],
 " to the Jupiter-Saturn system.  Note that we are using mean motions derived \
from Kepler's third law and we are setting J2 and J4 to be zero (i.e. there \
is no oblateness of the central body to consider)."
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"e62469f6-7147-47e0-a9d0-edeb822093c2"],

Cell[CellGroupData[{

Cell["\<\
secular[2, 
        {1./(1047.355), 1./(3498.500)},
        {5.202545297, 9.554840607},
        {0.047462192, 0.057548133},
        {1.30667, 2.48795} Degree,
        {13.983865305, 88.719424868} Degree,
        {100.0381, 113.1334} Degree,
        {360./5.202545297^(3/2), 360./9.554840607^(3/2)},
        0,
        0,
        0];
\
\>", "Input",
 AspectRatioFixed->True,
 CellLabel->"In[7]:=",ExpressionUUID->"857dc722-28aa-4132-99b2-fcba09c84fd1"],

Cell[BoxData["\<\"Mass ratios :\"\>"], "Print",
 CellChangeTimes->{3.81139653331144*^9, 3.867735892888442*^9, 
  3.867736655557932*^9, 3.890974905564678*^9},
 CellLabel->
  "During evaluation of \
In[7]:=",ExpressionUUID->"82390e79-5ff2-448a-8ff2-3c555d65be3a"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.0009547861040430418`", ",", "0.0002858367871945119`"}], 
  "}"}]], "Print",
 CellChangeTimes->{3.81139653331144*^9, 3.867735892888442*^9, 
  3.867736655557932*^9, 3.89097490556638*^9},
 CellLabel->
  "During evaluation of \
In[7]:=",ExpressionUUID->"61c76648-2533-43c7-bdfd-30e156d7f3d7"],

Cell[BoxData["\<\" \"\>"], "Print",
 CellChangeTimes->{3.81139653331144*^9, 3.867735892888442*^9, 
  3.867736655557932*^9, 3.89097490556777*^9},
 CellLabel->
  "During evaluation of \
In[7]:=",ExpressionUUID->"0629345a-f50b-43fd-afd7-ab5c49530d68"],

Cell[BoxData["\<\"Semi-major axes :\"\>"], "Print",
 CellChangeTimes->{3.81139653331144*^9, 3.867735892888442*^9, 
  3.867736655557932*^9, 3.890974905569072*^9},
 CellLabel->
  "During evaluation of \
In[7]:=",ExpressionUUID->"da56a87f-61a7-47a6-8f27-5a8f63731ec2"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"5.202545297`", ",", "9.554840607`"}], "}"}]], "Print",
 CellChangeTimes->{3.81139653331144*^9, 3.867735892888442*^9, 
  3.867736655557932*^9, 3.890974905570533*^9},
 CellLabel->
  "During evaluation of \
In[7]:=",ExpressionUUID->"7cbd508e-616b-487e-b774-1acd76aeda1f"],

Cell[BoxData["\<\" \"\>"], "Print",
 CellChangeTimes->{3.81139653331144*^9, 3.867735892888442*^9, 
  3.867736655557932*^9, 3.890974905571898*^9},
 CellLabel->
  "During evaluation of \
In[7]:=",ExpressionUUID->"f23f218b-c95e-4a5c-b5e0-de04255184c4"],

Cell[BoxData["\<\"Mean motions (degrees/year) :\"\>"], "Print",
 CellChangeTimes->{3.81139653331144*^9, 3.867735892888442*^9, 
  3.867736655557932*^9, 3.8909749055732393`*^9},
 CellLabel->
  "During evaluation of \
In[7]:=",ExpressionUUID->"8933496a-8b50-4d5d-9be7-160150567329"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"30.337423590928935`", ",", "12.18897905804579`"}], "}"}]], "Print",\

 CellChangeTimes->{3.81139653331144*^9, 3.867735892888442*^9, 
  3.867736655557932*^9, 3.890974905574739*^9},
 CellLabel->
  "During evaluation of \
In[7]:=",ExpressionUUID->"74587877-51d1-49dd-a665-2d1d2eedc430"],

Cell[BoxData["\<\" \"\>"], "Print",
 CellChangeTimes->{3.81139653331144*^9, 3.867735892888442*^9, 
  3.867736655557932*^9, 3.890974905576077*^9},
 CellLabel->
  "During evaluation of \
In[7]:=",ExpressionUUID->"f4659705-2030-4876-b118-d0ad6e26ed08"],

Cell[BoxData["\<\"Initial values :\"\>"], "Print",
 CellChangeTimes->{3.81139653331144*^9, 3.867735892888442*^9, 
  3.867736655557932*^9, 3.890974905577485*^9},
 CellLabel->
  "During evaluation of \
In[7]:=",ExpressionUUID->"a7d0a4c5-6437-4595-801c-57c8b42b375e"],

Cell[BoxData["\<\"==============  \"\>"], "Print",
 CellChangeTimes->{3.81139653331144*^9, 3.867735892888442*^9, 
  3.867736655557932*^9, 3.890974905578957*^9},
 CellLabel->
  "During evaluation of \
In[7]:=",ExpressionUUID->"c76d3b7d-734e-4df4-a682-41dcf4418433"],

Cell[BoxData["\<\" \"\>"], "Print",
 CellChangeTimes->{3.81139653331144*^9, 3.867735892888442*^9, 
  3.867736655557932*^9, 3.890974905580286*^9},
 CellLabel->
  "During evaluation of \
In[7]:=",ExpressionUUID->"5ee1c969-e0d8-4a94-9aac-e64f6f1cf9ff"],

Cell[BoxData["\<\"Eccentricities :\"\>"], "Print",
 CellChangeTimes->{3.81139653331144*^9, 3.867735892888442*^9, 
  3.867736655557932*^9, 3.8909749055816*^9},
 CellLabel->
  "During evaluation of \
In[7]:=",ExpressionUUID->"e20f2e4a-1da5-40d5-b14c-840b09fcf8d3"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.047462192`", ",", "0.057548133`"}], "}"}]], "Print",
 CellChangeTimes->{3.81139653331144*^9, 3.867735892888442*^9, 
  3.867736655557932*^9, 3.8909749055829277`*^9},
 CellLabel->
  "During evaluation of \
In[7]:=",ExpressionUUID->"2cc7d777-8c14-40a1-ba50-d18a8d462058"],

Cell[BoxData["\<\" \"\>"], "Print",
 CellChangeTimes->{3.81139653331144*^9, 3.867735892888442*^9, 
  3.867736655557932*^9, 3.8909749055842247`*^9},
 CellLabel->
  "During evaluation of \
In[7]:=",ExpressionUUID->"7b704843-4ec0-4e50-bb5e-bb788f299fe0"],

Cell[BoxData["\<\"Longitudes of pericentre :\"\>"], "Print",
 CellChangeTimes->{3.81139653331144*^9, 3.867735892888442*^9, 
  3.867736655557932*^9, 3.89097490558563*^9},
 CellLabel->
  "During evaluation of \
In[7]:=",ExpressionUUID->"61eecce6-45fa-409b-8804-2896c0ce5dc1"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.24406449172765107`", ",", "1.5484460744223356`"}], 
  "}"}]], "Print",
 CellChangeTimes->{3.81139653331144*^9, 3.867735892888442*^9, 
  3.867736655557932*^9, 3.8909749055870037`*^9},
 CellLabel->
  "During evaluation of \
In[7]:=",ExpressionUUID->"e2e174d2-7d67-4146-b29d-e2af169f0732"],

Cell[BoxData["\<\" \"\>"], "Print",
 CellChangeTimes->{3.81139653331144*^9, 3.867735892888442*^9, 
  3.867736655557932*^9, 3.890974905588357*^9},
 CellLabel->
  "During evaluation of \
In[7]:=",ExpressionUUID->"062630b7-bf68-40b9-a86a-f822dd3153cb"],

Cell[BoxData["\<\"Inclinations :\"\>"], "Print",
 CellChangeTimes->{3.81139653331144*^9, 3.867735892888442*^9, 
  3.867736655557932*^9, 3.890974905589683*^9},
 CellLabel->
  "During evaluation of \
In[7]:=",ExpressionUUID->"4e35f010-4110-45e8-98ae-433051226a8e"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.022805693737034307`", ",", "0.04342291912499292`"}], 
  "}"}]], "Print",
 CellChangeTimes->{3.81139653331144*^9, 3.867735892888442*^9, 
  3.867736655557932*^9, 3.8909749055910797`*^9},
 CellLabel->
  "During evaluation of \
In[7]:=",ExpressionUUID->"274e13a6-314d-46e1-8fe4-c91bc67cf8f3"],

Cell[BoxData["\<\" \"\>"], "Print",
 CellChangeTimes->{3.81139653331144*^9, 3.867735892888442*^9, 
  3.867736655557932*^9, 3.890974905592407*^9},
 CellLabel->
  "During evaluation of \
In[7]:=",ExpressionUUID->"73f4ccb7-9ee7-4383-a169-004e4991a5c9"],

Cell[BoxData["\<\"Longitudes of ascending node :\"\>"], "Print",
 CellChangeTimes->{3.81139653331144*^9, 3.867735892888442*^9, 
  3.867736655557932*^9, 3.890974905593646*^9},
 CellLabel->
  "During evaluation of \
In[7]:=",ExpressionUUID->"24a3cb1b-970e-4401-a1a4-bd42386d58f6"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1.7459942224393394`", ",", "1.9745503239757527`"}], "}"}]], "Print",\

 CellChangeTimes->{3.81139653331144*^9, 3.867735892888442*^9, 
  3.867736655557932*^9, 3.8909749055949717`*^9},
 CellLabel->
  "During evaluation of \
In[7]:=",ExpressionUUID->"274ca06b-b1aa-46cf-bbbe-9badfcc68e4c"],

Cell[BoxData["\<\" \"\>"], "Print",
 CellChangeTimes->{3.81139653331144*^9, 3.867735892888442*^9, 
  3.867736655557932*^9, 3.8909749055962763`*^9},
 CellLabel->
  "During evaluation of \
In[7]:=",ExpressionUUID->"61f61ef9-d48d-4653-84cf-d7c7f1ba25d4"],

Cell[BoxData["\<\"Matrix A (deg/yr):\"\>"], "Print",
 CellChangeTimes->{3.81139653331144*^9, 3.867735892888442*^9, 
  3.867736655557932*^9, 3.8909749056159782`*^9},
 CellLabel->
  "During evaluation of \
In[7]:=",ExpressionUUID->"66438dfc-b1aa-479e-baac-177a00c88175"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"0.002037382384210047`", 
      RowBox[{"-", "0.0013298659060103283`"}]},
     {
      RowBox[{"-", "0.003280064415541723`"}], "0.005025127292230189`"}
    },
    GridBoxAlignment->{"Columns" -> {{Center}}, "Rows" -> {{Baseline}}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Print",
 CellChangeTimes->{3.81139653331144*^9, 3.867735892888442*^9, 
  3.867736655557932*^9, 3.890974905618339*^9},
 CellLabel->
  "During evaluation of \
In[7]:=",ExpressionUUID->"1715508a-7e69-4b56-b7df-8ee1db55e441"],

Cell[BoxData["\<\" \"\>"], "Print",
 CellChangeTimes->{3.81139653331144*^9, 3.867735892888442*^9, 
  3.867736655557932*^9, 3.890974905620245*^9},
 CellLabel->
  "During evaluation of \
In[7]:=",ExpressionUUID->"e0ac2eb4-7e99-4f12-a7f3-9ac6817be439"],

Cell[BoxData["\<\"Matrix B (deg/yr):\"\>"], "Print",
 CellChangeTimes->{3.81139653331144*^9, 3.867735892888442*^9, 
  3.867736655557932*^9, 3.890974905621627*^9},
 CellLabel->
  "During evaluation of \
In[7]:=",ExpressionUUID->"7efeed8a-7a42-4201-8e66-67fa969776fe"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{"-", "0.002037382384210047`"}], "0.002037382384210047`"},
     {"0.00502512729223019`", 
      RowBox[{"-", "0.005025127292230189`"}]}
    },
    GridBoxAlignment->{"Columns" -> {{Center}}, "Rows" -> {{Baseline}}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Print",
 CellChangeTimes->{3.81139653331144*^9, 3.867735892888442*^9, 
  3.867736655557932*^9, 3.890974905623271*^9},
 CellLabel->
  "During evaluation of \
In[7]:=",ExpressionUUID->"646911c6-189f-453c-a3fd-d19ea0b70e5d"],

Cell[BoxData["\<\" \"\>"], "Print",
 CellChangeTimes->{3.81139653331144*^9, 3.867735892888442*^9, 
  3.867736655557932*^9, 3.890974905624608*^9},
 CellLabel->
  "During evaluation of \
In[7]:=",ExpressionUUID->"3587c037-d424-4e14-b1aa-5938d924acaf"],

Cell[BoxData["\<\"g eigenfrequencies (deg/yr) :\"\>"], "Print",
 CellChangeTimes->{3.81139653331144*^9, 3.867735892888442*^9, 
  3.867736655557932*^9, 3.89097490562584*^9},
 CellLabel->
  "During evaluation of \
In[7]:=",ExpressionUUID->"73c2c590-9d40-4e48-a78f-1b245df7a776"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.006099075070361905`", ",", "0.0009634346060783307`"}], 
  "}"}]], "Print",
 CellChangeTimes->{3.81139653331144*^9, 3.867735892888442*^9, 
  3.867736655557932*^9, 3.890974905627157*^9},
 CellLabel->
  "During evaluation of \
In[7]:=",ExpressionUUID->"32fda3e4-83de-4f48-88f0-c67bc425470e"],

Cell[BoxData["\<\" \"\>"], "Print",
 CellChangeTimes->{3.81139653331144*^9, 3.867735892888442*^9, 
  3.867736655557932*^9, 3.8909749056284227`*^9},
 CellLabel->
  "During evaluation of \
In[7]:=",ExpressionUUID->"827e6bf0-8e4d-427c-9842-9edc7bb1a6ba"],

Cell[BoxData["\<\"g eigenvectors :\"\>"], "Print",
 CellChangeTimes->{3.81139653331144*^9, 3.867735892888442*^9, 
  3.867736655557932*^9, 3.89097490562965*^9},
 CellLabel->
  "During evaluation of \
In[7]:=",ExpressionUUID->"6ad3867f-27e9-4d1e-b3b9-a1364322fb79"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"0.3111626228257313`", 
      RowBox[{"-", "0.9503566815444672`"}]},
     {
      RowBox[{"-", "0.7779911306128082`"}], 
      RowBox[{"-", "0.62827525869463`"}]}
    },
    GridBoxAlignment->{"Columns" -> {{Center}}, "Rows" -> {{Baseline}}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Print",
 CellChangeTimes->{3.81139653331144*^9, 3.867735892888442*^9, 
  3.867736655557932*^9, 3.890974905631072*^9},
 CellLabel->
  "During evaluation of \
In[7]:=",ExpressionUUID->"8420584a-5813-4579-ac60-252a9ce2bc25"],

Cell[BoxData["\<\" \"\>"], "Print",
 CellChangeTimes->{3.81139653331144*^9, 3.867735892888442*^9, 
  3.867736655557932*^9, 3.8909749056324863`*^9},
 CellLabel->
  "During evaluation of \
In[7]:=",ExpressionUUID->"bba5bae4-75e4-4c3a-a20b-e12e082cea2b"],

Cell[BoxData["\<\"f eigenfrequencies (deg/yr) :\"\>"], "Print",
 CellChangeTimes->{3.81139653331144*^9, 3.867735892888442*^9, 
  3.867736655557932*^9, 3.8909749056337957`*^9},
 CellLabel->
  "During evaluation of \
In[7]:=",ExpressionUUID->"7b6fa1b5-f061-4823-af26-f1baf6343f90"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "0.007062509676440236`"}], ",", "0.`"}], "}"}]], "Print",
 CellChangeTimes->{3.81139653331144*^9, 3.867735892888442*^9, 
  3.867736655557932*^9, 3.890974905635159*^9},
 CellLabel->
  "During evaluation of \
In[7]:=",ExpressionUUID->"ac88a49d-7fc7-4a6f-b04e-4284363006a1"],

Cell[BoxData["\<\" \"\>"], "Print",
 CellChangeTimes->{3.81139653331144*^9, 3.867735892888442*^9, 
  3.867736655557932*^9, 3.8909749056364717`*^9},
 CellLabel->
  "During evaluation of \
In[7]:=",ExpressionUUID->"f2f8d0b3-d4ae-4d43-a5a9-5c9901c8f56b"],

Cell[BoxData["\<\"f eigenvectors :\"\>"], "Print",
 CellChangeTimes->{3.81139653331144*^9, 3.867735892888442*^9, 
  3.867736655557932*^9, 3.8909749056377373`*^9},
 CellLabel->
  "During evaluation of \
In[7]:=",ExpressionUUID->"36b12b78-3df6-44de-8a74-598f5d46f8d5"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{"-", "0.37573181540105655`"}], "0.9267284407502699`"},
     {"0.7071067811865475`", "0.7071067811865476`"}
    },
    GridBoxAlignment->{"Columns" -> {{Center}}, "Rows" -> {{Baseline}}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Print",
 CellChangeTimes->{3.81139653331144*^9, 3.867735892888442*^9, 
  3.867736655557932*^9, 3.8909749056391582`*^9},
 CellLabel->
  "During evaluation of \
In[7]:=",ExpressionUUID->"fb8be450-7145-450f-82d0-902991ace50c"],

Cell[BoxData["\<\" \"\>"], "Print",
 CellChangeTimes->{3.81139653331144*^9, 3.867735892888442*^9, 
  3.867736655557932*^9, 3.890974905640527*^9},
 CellLabel->
  "During evaluation of \
In[7]:=",ExpressionUUID->"fb1e9223-1e66-4252-a133-d56a51e8069c"],

Cell[BoxData["\<\"Initial h values :\"\>"], "Print",
 CellChangeTimes->{3.81139653331144*^9, 3.867735892888442*^9, 
  3.867736655557932*^9, 3.8909749056417723`*^9},
 CellLabel->
  "During evaluation of \
In[7]:=",ExpressionUUID->"5feca409-963f-4a2a-8a23-ef2d9a11453b"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.011469174494143752`", ",", "0.057533759980095495`"}], 
  "}"}]], "Print",
 CellChangeTimes->{3.81139653331144*^9, 3.867735892888442*^9, 
  3.867736655557932*^9, 3.890974905643136*^9},
 CellLabel->
  "During evaluation of \
In[7]:=",ExpressionUUID->"eee557c3-6f97-4944-870b-2c4e8f3a7a5e"],

Cell[BoxData["\<\" \"\>"], "Print",
 CellChangeTimes->{3.81139653331144*^9, 3.867735892888442*^9, 
  3.867736655557932*^9, 3.8909749056443777`*^9},
 CellLabel->
  "During evaluation of \
In[7]:=",ExpressionUUID->"8184dc6f-2a86-4306-80b1-7cdc447d4511"],

Cell[BoxData["\<\"Initial k values :\"\>"], "Print",
 CellChangeTimes->{3.81139653331144*^9, 3.867735892888442*^9, 
  3.867736655557932*^9, 3.890974905645619*^9},
 CellLabel->
  "During evaluation of \
In[7]:=",ExpressionUUID->"a4e64e3b-ed5c-4e26-b2cc-b4746bf3cc14"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.04605559364363623`", ",", "0.0012861082141292612`"}], 
  "}"}]], "Print",
 CellChangeTimes->{3.81139653331144*^9, 3.867735892888442*^9, 
  3.867736655557932*^9, 3.890974905646885*^9},
 CellLabel->
  "During evaluation of \
In[7]:=",ExpressionUUID->"2be1b974-05ec-4628-9c4d-6e64e963c131"],

Cell[BoxData["\<\" \"\>"], "Print",
 CellChangeTimes->{3.81139653331144*^9, 3.867735892888442*^9, 
  3.867736655557932*^9, 3.89097490564821*^9},
 CellLabel->
  "During evaluation of \
In[7]:=",ExpressionUUID->"09c59a2c-fc5a-4c4e-8bf3-7cb56e4c22ec"],

Cell[BoxData["\<\"Initial p values :\"\>"], "Print",
 CellChangeTimes->{3.81139653331144*^9, 3.867735892888442*^9, 
  3.867736655557932*^9, 3.8909749056495523`*^9},
 CellLabel->
  "During evaluation of \
In[7]:=",ExpressionUUID->"bca4bc82-d315-4573-9b01-d6ac33ec1f3d"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.022456585645556557`", ",", "0.03993139648993428`"}], 
  "}"}]], "Print",
 CellChangeTimes->{3.81139653331144*^9, 3.867735892888442*^9, 
  3.867736655557932*^9, 3.890974905650922*^9},
 CellLabel->
  "During evaluation of \
In[7]:=",ExpressionUUID->"c2ea444a-89e5-4e19-a37a-1baf2facf2a3"],

Cell[BoxData["\<\" \"\>"], "Print",
 CellChangeTimes->{3.81139653331144*^9, 3.867735892888442*^9, 
  3.867736655557932*^9, 3.8909749056521473`*^9},
 CellLabel->
  "During evaluation of \
In[7]:=",ExpressionUUID->"2c53296f-a5b7-408a-8404-0e0eb8e7ef10"],

Cell[BoxData["\<\"Initial q values :\"\>"], "Print",
 CellChangeTimes->{3.81139653331144*^9, 3.867735892888442*^9, 
  3.867736655557932*^9, 3.89097490565339*^9},
 CellLabel->
  "During evaluation of \
In[7]:=",ExpressionUUID->"55b8bdc8-dd28-43a3-814c-c18e7f490c4c"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "0.0039751010013821`"}], ",", 
   RowBox[{"-", "0.0170597033883752`"}]}], "}"}]], "Print",
 CellChangeTimes->{3.81139653331144*^9, 3.867735892888442*^9, 
  3.867736655557932*^9, 3.890974905654744*^9},
 CellLabel->
  "During evaluation of \
In[7]:=",ExpressionUUID->"ee05f6b4-ba9c-4664-82c2-891138c519f3"],

Cell[BoxData["\<\" \"\>"], "Print",
 CellChangeTimes->{3.81139653331144*^9, 3.867735892888442*^9, 
  3.867736655557932*^9, 3.890974905656055*^9},
 CellLabel->
  "During evaluation of \
In[7]:=",ExpressionUUID->"69af9ed0-e610-4310-a9c2-6f69a272b8e9"],

Cell[BoxData["\<\"Beta (deg) :\"\>"], "Print",
 CellChangeTimes->{3.81139653331144*^9, 3.867735892888442*^9, 
  3.867736655557932*^9, 3.8909749056573973`*^9},
 CellLabel->
  "During evaluation of \
In[7]:=",ExpressionUUID->"950ce144-a5c2-4c6f-896f-f7baf45968e2"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "53.35652579154743`"}], ",", 
   RowBox[{"-", "146.89228735922418`"}]}], "}"}]], "Print",
 CellChangeTimes->{3.81139653331144*^9, 3.867735892888442*^9, 
  3.867736655557932*^9, 3.89097490565876*^9},
 CellLabel->
  "During evaluation of \
In[7]:=",ExpressionUUID->"506ce087-4651-4fa6-a93f-e041946b1bc3"],

Cell[BoxData["\<\" \"\>"], "Print",
 CellChangeTimes->{3.81139653331144*^9, 3.867735892888442*^9, 
  3.867736655557932*^9, 3.8909749056600657`*^9},
 CellLabel->
  "During evaluation of \
In[7]:=",ExpressionUUID->"a610bc02-db87-459b-8225-3af452f3e6f3"],

Cell[BoxData["\<\"Gamma (deg) :\"\>"], "Print",
 CellChangeTimes->{3.81139653331144*^9, 3.867735892888442*^9, 
  3.867736655557932*^9, 3.890974905661302*^9},
 CellLabel->
  "During evaluation of \
In[7]:=",ExpressionUUID->"ef85e237-a183-42a6-aa13-85a9bf7bf480"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"126.82474313164487`", ",", "105.73953087222233`"}], "}"}]], "Print",\

 CellChangeTimes->{3.81139653331144*^9, 3.867735892888442*^9, 
  3.867736655557932*^9, 3.890974905662734*^9},
 CellLabel->
  "During evaluation of \
In[7]:=",ExpressionUUID->"da457e21-c6fe-4793-a20c-a0c8864e0fc0"],

Cell[BoxData["\<\" \"\>"], "Print",
 CellChangeTimes->{3.81139653331144*^9, 3.867735892888442*^9, 
  3.867736655557932*^9, 3.8909749056640577`*^9},
 CellLabel->
  "During evaluation of \
In[7]:=",ExpressionUUID->"cdb9ef3f-d5b0-41ce-abbd-8ead1cf97cac"],

Cell[BoxData["\<\"Scaled h-k eigenvectors :\"\>"], "Print",
 CellChangeTimes->{3.81139653331144*^9, 3.867735892888442*^9, 
  3.867736655557932*^9, 3.8909749056653767`*^9},
 CellLabel->
  "During evaluation of \
In[7]:=",ExpressionUUID->"fc94780b-1997-4383-8ec1-b8d94c596947"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"0.015578798592281971`", 
      RowBox[{"-", "0.04388211060645147`"}]},
     {
      RowBox[{"-", "0.047580956858377495`"}], 
      RowBox[{"-", "0.035437479051487746`"}]}
    },
    GridBoxAlignment->{"Columns" -> {{Center}}, "Rows" -> {{Baseline}}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Print",
 CellChangeTimes->{3.81139653331144*^9, 3.867735892888442*^9, 
  3.867736655557932*^9, 3.890974905666875*^9},
 CellLabel->
  "During evaluation of \
In[7]:=",ExpressionUUID->"89b5e781-26a2-4a9c-9605-ed41594a3a42"],

Cell[BoxData["\<\" \"\>"], "Print",
 CellChangeTimes->{3.81139653331144*^9, 3.867735892888442*^9, 
  3.867736655557932*^9, 3.890974905668255*^9},
 CellLabel->
  "During evaluation of \
In[7]:=",ExpressionUUID->"5926c5c5-c733-427f-b16e-92c1b4f999aa"],

Cell[BoxData["\<\"Scaled p-q eigenvectors :\"\>"], "Print",
 CellChangeTimes->{3.81139653331144*^9, 3.867735892888442*^9, 
  3.867736655557932*^9, 3.890974905669486*^9},
 CellLabel->
  "During evaluation of \
In[7]:=",ExpressionUUID->"7911b011-9ee1-4495-99cb-3a57561a8b41"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{"-", "0.006297664190201552`"}], "0.028568889014972485`"},
     {"0.01553295269692481`", "0.02856888901497249`"}
    },
    GridBoxAlignment->{"Columns" -> {{Center}}, "Rows" -> {{Baseline}}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Print",
 CellChangeTimes->{3.81139653331144*^9, 3.867735892888442*^9, 
  3.867736655557932*^9, 3.890974905670994*^9},
 CellLabel->
  "During evaluation of \
In[7]:=",ExpressionUUID->"6ed52ae4-14aa-4613-973c-1e66e91af982"],

Cell[BoxData["\<\" \"\>"], "Print",
 CellChangeTimes->{3.81139653331144*^9, 3.867735892888442*^9, 
  3.867736655557932*^9, 3.890974905672347*^9},
 CellLabel->
  "During evaluation of \
In[7]:=",ExpressionUUID->"d6377d1b-4ad4-47ff-ae2d-81cbd10df593"]
}, Open  ]],

Cell[TextData[{
 "The function ",
 StyleBox["secular", "Input"],
 " has also defined a function ",
 StyleBox["ejcalc", "Input"],
 " that returns the eccentricity of any of the bodies at a specific time. We \
can use this to derive Eq.(7.52)."
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"710d2172-b75e-4f02-bd8e-aa87cd85d443"],

Cell[CellGroupData[{

Cell["Chop[FullSimplify[ejcalc[1,t]]]", "Input",
 CellLabel->"In[9]:=",ExpressionUUID->"ccba448d-6c91-443c-94cc-42c522113d36"],

Cell[BoxData[
 SqrtBox[
  RowBox[{"0.002168338596855727`", "\[VeryThinSpace]", "-", 
   RowBox[{"0.0013672611258842959`", " ", 
    RowBox[{"Cos", "[", 
     RowBox[{"1.6325070077163324`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.00008963383530039862`", " ", "t"}]}], "]"}]}]}]]], "Output",
 CellChangeTimes->{3.8113965334704514`*^9, 3.867735893560945*^9, 
  3.867736655790894*^9, 3.890974905735738*^9},
 CellLabel->"Out[9]=",ExpressionUUID->"29366a73-0318-4d68-a41b-48c90dd87239"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Chop[FullSimplify[ejcalc[2,t]]]", "Input",
 AspectRatioFixed->True,
 CellLabel->"In[10]:=",ExpressionUUID->"4c549b27-c282-4bbc-8495-e53f03b7025a"],

Cell[BoxData[
 SqrtBox[
  RowBox[{"0.003519762377083413`", "\[VeryThinSpace]", "+", 
   RowBox[{"0.0033722983238369895`", " ", 
    RowBox[{"Cos", "[", 
     RowBox[{"1.6325070077163324`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.00008963383530039862`", " ", "t"}]}], "]"}]}]}]]], "Output",
 CellChangeTimes->{3.811396533519546*^9, 3.867735893604952*^9, 
  3.867736655828102*^9, 3.8909749057669353`*^9},
 CellLabel->"Out[10]=",ExpressionUUID->"cd492e85-34c1-4a82-872d-e18ce9b86805"]
}, Open  ]],

Cell["Convert some of the constants for a proper comparison.", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"1e9a84a8-55da-4a7a-ae62-dbe7a5b67297"],

Cell[CellGroupData[{

Cell["N[0.0000896338/Degree]", "Input",
 AspectRatioFixed->True,
 CellLabel->"In[11]:=",ExpressionUUID->"11ff5ff5-828d-4a60-8f2a-279fb77096cf"],

Cell[BoxData["0.005135638441719719`"], "Output",
 CellChangeTimes->{3.811396533523951*^9, 3.86773589363136*^9, 
  3.867736655849366*^9, 3.890974905773337*^9},
 CellLabel->"Out[11]=",ExpressionUUID->"3a34cb50-1056-4c03-9f7c-f81c097e5d78"]
}, Open  ]],

Cell[CellGroupData[{

Cell["N[1.63251/Degree]", "Input",
 AspectRatioFixed->True,
 CellLabel->"In[12]:=",ExpressionUUID->"5bd21521-0d3b-44fa-8392-cc38b4d4456d"],

Cell[BoxData["93.53593301290202`"], "Output",
 CellChangeTimes->{3.811396533571162*^9, 3.867735893668271*^9, 
  3.86773665587781*^9, 3.8909749057856083`*^9},
 CellLabel->"Out[12]=",ExpressionUUID->"4d066b08-0194-4590-9105-eba13493f36b"]
}, Open  ]],

Cell[TextData[{
 "The function ",
 StyleBox["secular", "Input"],
 " has also defined a function ",
 StyleBox["ijcalc", "Input"],
 " that returns the inclination of any of the bodies at a specific time. We \
can use this to derive Eq.(7.53)."
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"4144d348-7f5a-42a9-90f5-b2fb4a4b38ee"],

Cell[CellGroupData[{

Cell["Chop[FullSimplify[ijcalc[1,t]]]", "Input",
 AspectRatioFixed->True,
 CellLabel->"In[13]:=",ExpressionUUID->"7be96441-07da-46ae-8c48-d1b95c822372"],

Cell[BoxData[
 SqrtBox[
  RowBox[{"0.0008558419938023625`", "\[VeryThinSpace]", "-", 
   RowBox[{"0.0003357423269749568`", " ", 
    RowBox[{"Cos", "[", 
     RowBox[{"0.00012326404730784153`", " ", "t"}], "]"}]}], "-", 
   RowBox[{"0.00012945263632641797`", " ", 
    RowBox[{"Sin", "[", 
     RowBox[{"0.00012326404730784153`", " ", "t"}], "]"}]}]}]]], "Output",
 CellChangeTimes->{3.811396533620422*^9, 3.867735893705855*^9, 
  3.867736655906865*^9, 3.89097490580824*^9},
 CellLabel->"Out[13]=",ExpressionUUID->"f5ff6bc4-ecaa-4def-9f82-9613dba02f69"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Chop[FullSimplify[ijcalc[2,t]]]", "Input",
 AspectRatioFixed->True,
 CellLabel->"In[14]:=",ExpressionUUID->"915be487-a204-4026-beea-cf2795772640"],

Cell[BoxData[
 SqrtBox[
  RowBox[{"0.0010574540390347195`", "\[VeryThinSpace]", "+", 
   RowBox[{"0.0008280958663009567`", " ", 
    RowBox[{"Cos", "[", 
     RowBox[{"0.00012326404730784153`", " ", "t"}], "]"}]}], "+", 
   RowBox[{"0.0003192900757838132`", " ", 
    RowBox[{"Sin", "[", 
     RowBox[{"0.00012326404730784153`", " ", "t"}], "]"}]}]}]]], "Output",
 CellChangeTimes->{3.811396533669244*^9, 3.8677358937871447`*^9, 
  3.867736655935315*^9, 3.890974905827755*^9},
 CellLabel->"Out[14]=",ExpressionUUID->"2e860df4-e23c-4184-86d7-12e26b9e6cb2"]
}, Open  ]],

Cell["Convert some of the constants for a proper comparison.", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"fd03c01e-928d-4843-aa00-23d5b178a19e"],

Cell[CellGroupData[{

Cell["N[0.368006/Degree]", "Input",
 AspectRatioFixed->True,
 CellLabel->"In[15]:=",ExpressionUUID->"a35aed60-87fc-4c3a-a3df-fa3cbbe54ffd"],

Cell[BoxData["21.085190635491372`"], "Output",
 CellChangeTimes->{3.811396533673615*^9, 3.867735893809078*^9, 
  3.867736655957164*^9, 3.89097490583467*^9},
 CellLabel->"Out[15]=",ExpressionUUID->"11160cf1-bd95-4cd2-9adf-f59cff49d892"]
}, Open  ]],

Cell[CellGroupData[{

Cell["N[0.000123264/Degree]", "Input",
 AspectRatioFixed->True,
 CellLabel->"In[16]:=",ExpressionUUID->"bfb5f243-9d30-4205-ae02-20b7bf1c1a1d"],

Cell[BoxData["0.007062506965900579`"], "Output",
 CellChangeTimes->{3.8113965337232*^9, 3.867735893840794*^9, 
  3.86773665598577*^9, 3.890974905847273*^9},
 CellLabel->"Out[16]=",ExpressionUUID->"c653b09d-8a98-477a-adaa-b32aaf9b6e00"]
}, Open  ]],

Cell["\<\
Define the labels for the plot of the variation in eccentricity.\
\>", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.8660041264449883`*^9, 3.8660041325640097`*^9}, {
  3.866029890140891*^9, 3.86602993667218*^9}, {3.866282127527829*^9, 
  3.866282190002166*^9}, {3.8662822302172823`*^9, 3.866282329322722*^9}, {
  3.866282369853121*^9, 3.866282394453143*^9}, {3.866282430858724*^9, 
  3.866282540539081*^9}, {3.8662825762398033`*^9, 3.866282618870384*^9}, {
  3.86628265396905*^9, 3.866282718243656*^9}, {3.866282806084441*^9, 
  3.8662828748935623`*^9}, {3.866282924052142*^9, 3.866283055107532*^9}, {
  3.866283118843275*^9, 3.866283158113332*^9}, {3.8663531452119713`*^9, 
  3.866353164696291*^9}, {3.866370479072535*^9, 3.8663705310635977`*^9}, {
  3.86637056805311*^9, 3.866371011248748*^9}, {3.8663711909578657`*^9, 
  3.866371259808771*^9}, {3.8663717081320677`*^9, 3.866371711221586*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"90fe4803-20d1-48f0-b16d-f30542d276bb"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"xlabel", "=", "\"\<Time (years)\>\""}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ylabel", "=", "\"\<\!\(\*TemplateBox[<|\"boxes\" -> FormBox[
RowBox[{\" \", 
StyleBox[\"e\", \"TI\"]}], TraditionalForm], \"errors\" -> {}, \"input\" -> \
\"\\\\,e\", \"state\" -> \"Boxes\"|>,\"TeXAssistantTemplate\"]\)\>\""}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.866019997647851*^9, 3.86601999950765*^9}, {
  3.866020049819096*^9, 3.866020058133103*^9}, {3.866363320190296*^9, 
  3.866363332819825*^9}, {3.8663634018648233`*^9, 3.866363457637225*^9}, {
  3.866363633695195*^9, 3.866363635415345*^9}, {3.867734127182289*^9, 
  3.867734137035391*^9}},
 CellLabel->"In[17]:=",ExpressionUUID->"b37d94ff-ebca-45f6-a9de-04d65a2aa42a"],

Cell["\<\
Now plot the evolution of the eccentricities of Jupiter and Saturn as a \
function of time.  This is Fig.7.1a.\
\>", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.867734051902104*^9, 3.86773406308488*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"30238e04-ba0e-4c82-9b9f-17345e4ea5be"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"ejcalc", "[", 
      RowBox[{"1", ",", "t"}], "]"}], ",", 
     RowBox[{"ejcalc", "[", 
      RowBox[{"2", ",", "t"}], "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", 
     RowBox[{"-", "100000"}], ",", "100000"}], "}"}], ",", "\n", 
   RowBox[{"PlotRange", "->", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "100000"}], ",", "100000"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0.1"}], "}"}]}], "}"}]}], ",", 
   RowBox[{"Frame", "->", "True"}], ",", "\n", 
   RowBox[{"FrameStyle", "->", 
    RowBox[{"Thickness", "[", "0.004", "]"}]}], ",", "\n", "  ", 
   RowBox[{"FrameLabel", "->", 
    RowBox[{"{", 
     RowBox[{"xlabel", ",", "ylabel"}], "}"}]}], ",", 
   RowBox[{"RotateLabel", "->", "False"}], ",", "\n", "  ", 
   RowBox[{"AxesOrigin", "->", 
    RowBox[{"{", 
     RowBox[{"0", ",", "0"}], "}"}]}], ",", "\n", "  ", 
   RowBox[{"FrameTicks", "->", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", "0.04", ",", "0.08"}], "}"}], ",", "None"}], "}"}],
       ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "100000"}], ",", 
          RowBox[{"-", "50000"}], ",", "0", ",", "50000", ",", "100000"}], 
         "}"}], ",", "None"}], "}"}]}], "}"}]}], ",", "\n", "  ", 
   RowBox[{"LabelStyle", "\[Rule]", 
    RowBox[{"Directive", "[", 
     RowBox[{
      RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", 
      RowBox[{"FontSize", "\[Rule]", "16"}]}], "]"}]}], ",", "\n", "  ", 
   RowBox[{"PlotRangePadding", "\[Rule]", "None"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.867735665147388*^9, 3.8677356651591797`*^9}, {
  3.86773583002166*^9, 3.867735842694563*^9}, {3.867735927462843*^9, 
  3.8677359665821943`*^9}, {3.8677360358897877`*^9, 3.867736052638752*^9}, {
  3.867736089540036*^9, 3.867736183635832*^9}, {3.867736214236064*^9, 
  3.867736227120223*^9}, {3.867736281619112*^9, 3.8677362905409822`*^9}},
 CellLabel->"In[19]:=",ExpressionUUID->"03fa848a-dfdd-4269-a4dd-81fe8968595b"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
      1.], LineBox[CompressedData["
1:eJwtm3k01N8bx21R0iKh0KIkJSmhTT03oYV2oVKJyC5EkooIqVRSqXzGGmHm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       "]]},
     Annotation[#, "Charting`Private`Tag$2409#1"]& ], 
    TagBox[
     {RGBColor[0.880722, 0.611041, 0.142051], AbsoluteThickness[1.6], Opacity[
      1.], LineBox[CompressedData["
1:eJwtm3c81d8fxyWrEhXSlpJEEqHtfUhStIQUyUohI5WVSpFcZK8SZWRl33tT
Mo6Vkb2L7HHvNePeSyS/z/fx+P3l8Xw4870+53Ue54qb2evc4uTg4Di4koPj
v7/CmzWnlq3msdTdScUR51xQmcnwkLacx1HyKo6yT3PhznehDXpm8/j4VP0v
G+9c+Pq4VzHt+jxO16yQqw/LBbMBJzddrXlswKReksrJhZyPH7hT98/jlLBN
knK0XLigsnKbztQc/nJq+bDtRTK4iFpluI/N4Zq27RMhemSIn65XSR6dw0dG
7xpmGZKBHf/G9G/vHMajFvq1t8kQw6uQnNQ4hyttLKwjnpJhvNFEYTFnDkv2
vVS9k0EGknmRZuKDOSwhmfB4YgUFIhjx2u4Oc9gr0r32Ai8FEu+9vKR7dw4v
1X0qS+SnQNHTSwZcFnPYW3ok5oAoBWaiB25bXJnD0ev+Jn6RocD1Vp6XEgpz
mDcrVzFNhwK3Dcd8/8rOYeXOFm/dqxR4MNAQ0LpvDr88JHxx1pACAdNREV7i
czgl7ZaywC0KlPHLJA2tm8Ndl9av/+JEgf2nL1YkTrHxfrZweF8kBY7WHqp2
H2PjsCs8/xqjKaBxZVOd7igbC5agXOo7CpiY9rdy9bLxe63eGcNkCoQ/vj9k
Uc/GgQKkkK2fKBDPZUA7UcPGT1t0hTK/UCDb78S48Dc2ll1dVatYSIGa19zM
8kI29jTu79tRToF/1MiVezLYWDhcSudWEwXWnHTnXUph4wcl6kavWymwqdxk
TVsiG8fuOhVQ0kEBheZ9Qi/esrGp43qzyV/E/ie/7hr2Y+Nv50pDv9Ap0CjZ
p/rBmo2T9xgHCC9TQKV8qrLMko0vRD7vNVlBhXTT5fMDZsR6ntSXx6+kwsu3
O66LGbKxjPE/DV4+KqhsuOH4WouN+a7T+K6sI9pn3Z3PO8PGG9PO/dTaQIUt
592ftJ9iYz3vj8rHhKnAehntK3SCjY9bIv85UaL90o/4V/vZuJ76I4C5g2gf
TZdKl2Jj5WCZt693UsHnyJ/MGgk2/tRStF9xFxXM72/6yrudjUPWHG49u4cK
jeukVCU3s/GGPw70ckliPZmHK9VF2PiQSsQTJSliPLp+y7O1bEwy8NszJ02M
52157f0qNl6R8UtJcz8V2Ludeou42Zh2dWdZgCwVmo3DxxaXWHj7hfzLf+Wo
QGptWek0ycLnBw1krykS7e8NksIYLKx1dIeQvhIVLARnBckjLPxBdspBU5kK
6NyGbdM9LLypNiNk7REqZI6Kxwt0sbBbXJJeH8HbXshLyXaw8LRNSUDKUSrM
F19StG5g4VcDOaabj1PB8oZJvs93Fv54AS+UENy6YI+SK1l4Qs6Mz+QEFdSi
nn6rKGNh/T1qvrMEZykFag8Vs3CHxzoP95PE+C2xzZwFLHzjjCd9gWBfh0wD
8c8s/POg/jc7FWK+tUU9QGFhg5RzGzsJtvxYZ2GczcJL3/f+UAZiPs1fDPd0
Ft5hmy/gR7DayLhDdAoLo3Vtn1oJzvb8y/6SyMK7Ji42CSEqbBfnf9z5noWr
JvmMNQn2Ldq6cu4tC3uQB40cCZ43lCGJvGbhAf/qumCCLf8cE1QMJ9bzNDU7
ieDWiHPhOsEsnKLuwp1DsJri9a33XrHwiMbB2myCs5us4gJJLPz8QxPXf+13
2LvuzXzBwuUKZllBBPvxkzJqn7HwuQcT3x3+my816tDYYxbmS/C6rvHffGdS
vqxyY2H1jyqG6/+bbygPpJxYOGj/kfqm//b3vLJCw5FYv2so+SXBI4VVVS52
hD/FgusVCfb7U/09zZqFM0yUKjoIex1U+l7fbUnYj5Qd6UBwq0Ntk4A5C4tJ
H9FYJuztml7Xim6y8H1R3iZPgnfQ6jscDYn+VjeO/CP8dftm06/2Kywc+Ts/
ppXwL390cx/fJRY++NHo7UGCs9tbBo9ps7BlU77L82NUWDjfTo9VZ2FV3a21
vES8xJI6xhsRC0vqDJw6TsTTqYrOKc6TLLxqefKNxWEq+J/oYlkqEfsNeEuL
IuJT3qV7PkqehbfJ7u9LIOK3nfxrsUaWhWtmez4nHqKCmEzfCjlJFj6lWyHo
I0+Fcst+LtNdLHymbH2g9UEq3Ikf4A3dwcK3uMi/1Yh8yN08vHZuIzGf903z
NiJ/9PVG1u0TIuyZk3E/UIYKi0GjQoaCLLziRbsVEPmmzsfYXMzLwmUtzquf
7aVCB3tyz8t5JtbTvyHvJ04Fd4VpqS9MJo5Qwl5MMSrstPstMzbNxE8auMuv
EPXAenhW/iKdieW2xq1ibqHC35b5k6I/mdgiUaTmqxAV4gQX0Nl2Jp7deTu8
dT0VNLQWTz1qZuJ9xbNXBgWpEFi6dLa3holDb9RnDqyhwq4cTv3kr0xsyiP2
5w5Rz76Nr7z2I4+JqTn5j+SJemcjxW20hsLEYdNHF6b+UYDyjtfMPp2J/YWi
py4sUOBMAL/d4RgmVuUV6QmbpsBdm43elU+YmFHrOa7aRQGmbsRikhsTrz+w
P2t/JwXcVTbe83ZiYoV/30vWtFHAf/1Go9N2TFxQkNyTVE+B9DwRhbIbTFwp
ZXzgcgkFxlaK9BSdYOL77kt/nBMp4DgRdiX2CBPb0KxyU95TYKFduPqxIhNP
/BvvrntLgdVpwpQT+5nYTqkgmBVGAelLwr75W5nYseFTUb4XBazfCil/WpjF
Yv7BN3eYEd/HF6Efw9mz2OIw61bkDQq42QuJP5yZxSuyq3m5r1HAV02IX5Ex
izOOb9pXdJECabQNAzk/ZnHKWslDKScowFDcEJDxeRYXW3isNBamgFXdupFE
p1ls98Zt5e2vZNCp+/qrxnEWP+Fo39xLJcOxOsu2abtZ7HI0PPZ8Nhn46wrK
T9yexRd5bi6v/UCGzNo7Ca1XZ/Hlt/IPtgWQYfY7NuE6Oos37dObcDQmw+Ma
hy7zxRksl3z78vb5XLCs2dpCmpvBp1ZIP7L6TZxHar7VZM3O4M4bpU/SGbmw
s2Zb/uLYDG4cubJL9FculFZXRYV2z+BgyzPqT0tygbd6p35Z4QyOmea7FOuT
C8GVjY27PGbwws/tQYfW5YLRw4Vj7Ecz+M1e3qR83lyQ2i3xodp5BvN0fA8/
vJwD+Imzq4M9Md5tq81CkzkwrbRjV5HxDDZQO3np8vccuJRoc//ayRmctyYw
aMozBwSe8WwMWviNy/p/J/yayAa/YycMlx78xqPOf451aWVBgPdVtSGH37hh
LOZGrHIWBDU77vt+9zfednh612XxLIiwTp2LsviNoedt4wt2JsS/2RimqPsb
//wndU32fSZ8XpiutTn0G5+2LLB8Pp0BQ/kfVH7+nsaVxdfbcl+kw8njgrvy
7KZxRplqOONFKiimXBzdxZzEcaquoWpOCRDyvaM6qH8cWzgXDzxReg39mz6/
aPkxjmtV+D1vrnwNBy2jVDc2j+Mzn7L9rzZFQR3HtS/RpePYX0vsU7BtFPAp
/0xJShjHn0YsWs4lR8LT990vC26NY5qtlVftzgionyg4tXxjHMfrlpKSpsNh
2/GYZVX9cXzl69qBNBwO+W03nCs1xvGWz9ykI6bhwF7da9m8dxzzn/gsFpYY
Bncf9p+m0cdw8xbHBz+UQuFrackKmYExzP1x6N+eVaGwel18oe3PMTwsejAr
vzsEktPMlGZrxrB16BG+b14hMNA7KPHv4xhWcs5T/dgZDNfOjawUthvDbtsr
kyRCgiAl8luxvuUYNtK8337EJgjYQ0mPXhuPYf5eT4ly9SAIe3p7dsfFMSyy
Uu1xzEwgNFJoA/sOjmFR5qlLKk0BIMZZHXtXihjPpL4lwy8A7C6mXs/aOYZd
b9/2OHcmANYwrJoV14/hIfsfzbKlr0BDbKwEZhiYkfnIJLzSHzhTM51TGQxs
qObn4//KH4oVHGWFBhlYV1NHh6HrD0c0/kSNtDDw35nN9kujfsBsKLhwqZaB
Yyf3fSwn+0HONQ+u/HIG5uSQ19n4zA+kbXkdXlEZ+J7pGqr7Tj8YYdfsmctg
YGmvAZQw4wsJHgFdJkkM/Gbr6Vrnb76wLUzkjGIkAzf6ZgSdv+8LP7b/+BsT
SPTfK1pzU9sXIpLf5vL6MLBT3Xm26l5fEPy6e0eXCwNrrosQjhggQa36aIv6
PQbmdbExES0jgU99GinTioHPvRNRf/mBBKcN7GCTGQO32/VnjpNIwDkgz3p2
neAsncMXHEhQZMNKG9Mh+nvuFM41IMEj1mcTPS0GjjlpKbLjFAmOPHXfWHyK
sE/dpthIORIw+VCt1AkGbq5qjNm9gwTZISufhygS/YX/+H4TIIHttsrDf/cz
sJrHvRteK0ggneQ7cWsPA+twU0gmbB8YkbuQ0LCdgeMkff/emPCB+C/rrx3d
yMDbKo1Fn474wM1TbQIJAgxsI344o6LfB7bVRZXz8zIwd4chx6FeH+jUN3Jz
WqZja+EvuLLHB8L6xA72zdHxi+yF1V59PnDZenD47DQdH12wvHN7yAcEmEnR
ZBodDye6NDgwfKDmsfXl7f10PMCh/CF2xge8eQ/wvvxBx6qOqsWTf33gVPDv
gukmOl7LfGtpvIoEHFupjtdr6PjW/U2GDFESFCS6SJWX0nESy6QjQIoELgdO
9Mh+pWOnn4nhZ46TQOnzcmgkmY6FduFWwUskmFEtO7sinY7DXQduDFiSIPO7
97J1Ih1vGn/n++UpCWz0zlFb39JxqpuRVuAbEkj1rrVRCadj9xecB27kkSBu
Jqx9vTcdFzrtqa9gk8DY3cD/0RM6dj2hv3B5sy9s4dmmNuxEx79/XVb8ctIX
wjYnZHy+Tcd79ryqmffzhUsJlua7TOi4cUXwO0z1hbWy0pv9DejY9P34M7V+
X/BGOV43z9Kx+jWl3Msn/UCt5sGxalU6bvoabVpn6wfLV45MKxyjYxZPwETv
Oz9wuV1syCNDx4cFoPwDnz9YB9QpZPDTsd5Zrldfxvxh4n5A3T0uOuabkcgS
k30FDtcu3lH+S8OGr/fuXefwCpwkmmKKx2jYbvO14xYLr8Azv5WvuYaGg63P
VmeKBcLbka4etg8NB9y7KSrQHARitW9dv3rQsLa/VG/O3yCIz7kh7OFCw8d/
wrb6vcGQ4t57dtUdGn5+a+Mzk6fBQN0wSNl6hobzN3pleB8KgXoVhi/ipuGL
L9fqL6SHwmWJj3u4l0Zx6LUtZn6/QqF11V1czRzFRp9bXMwEwuBn6wRLZ2gU
H+pgK/1wCINR698mt8pGsVve+ELqkXDgiJxX9n02ineK6cqJNkfAoSmewZal
ESx062FK5843oOPxPeX4hmGcY5x5i882AURWjmYYLQ3gL/V557M40iAgo0fm
IGsAz/CHvNu7OQ14DNpTV04M4PjVfM6h8mkwn17xIa17AGt/OH37tFkadOsn
xsx/HcC2pKi968rSID7N9FWY2wC+myBqdvD5Rzig0323dq4fkw+svreVnQ6a
cU0yJ2b6sPPD64uM7Cx47iKW+ZbRhwfUuMd0yrOg4KLtwaWBPryx85VxekcW
HPzHp1TU0ofNHd8lHPqXBZsNkQqi9mGenq+KZ/dkA0M465K6Sx9epAlGnHLI
hi3rN49F/e3FkhcW5J9x5EBAMWXq2kQvtnAwaVNblQOcdpeYW3p68e4/RkF/
1+fAWM3LpbfFvfj0R/OjBrtzoMCLLRj3vBdfSWDVZ53OAeP5FsVUvl58OPNJ
W5dPDiT0Bjz5ItyDVxWbD/GsyoXE03vOH+TqwdyBjfZW63Mh6ePXrcmzv3CX
awxH6eZcSHGmfQ5r/oUnf9Rs05POhUxBtVn7IOL/XZDGqZUL+cC6Lcn/C0+0
+/o4+eZC0zvDy6Eru3HpquVLsSvI0Mw9I7Z6tgu32l/+kMdHhlYbn0mPgS4s
Fttg8k2QDO2HqX52JV34aLbTYtl2MnQ3CHw7+7QLT3tuU4ejZKAtlxzjWPyJ
rz3baaJgR4blm1IStjM/sLDE/v2TDWTwErNZXBr4gf/8YGafayMDX29Gc0DL
D9zYp+Eb85MM64wPPcum/MB6N9kHJIfJsNNIpWfW6Qcmj5ZNl/4hg6qBbpTb
YifeLX6QsVecAt9EI+3XjHfivs9cd2h7KHCu44fG2+5OrKf+TuCdNAV09G+y
Cgs7saII+/vkIQqY6VrrrPDoxLHiAiWiGhTwvOTB78PVid9cEXV6dYcCfOvK
BjexOnBTscD1rLvE+biB+2vqcAdWSvVFlQ4UCLvgZ/X9WwfmfIr4f7hQIFE7
gijzHViQtt/My4cCFZrpHuFrOzDluJXy/AdiPXxTVyX/teMVPBWnXVMpUF8p
L5c32Y6no0eVp9Mp0K6R96uzoR3v4hbKKyZTYES99Ni2kHYsekHp7xCmAK9q
JzN+Yzu2/WUicuYHBTZ9Fomgc7fjy8wr+mbdxPla7srhg6w2nPSeHn6vlwLa
2+tdC1vasN6Vi6vuDlMg5E/Zv46gNty4asa/kdAHCQ4r3u/waMNN6rkBfrOE
nhhVUb1l34Zjhz08jrEp0NH2xXPmfBtOuB8k+2CRAttys/jWrmnDy9SNHvrc
VJDdN5F6ZaEV94XktmbzUkHlvbTWG3orfjCUw7+8igqmAR9e7a1qxdU1G8Wd
BaiQZB29Qe1FKz4fWU1p20iFvP5Oss+DVnzaPXqpfhMVqgw26jWYt2KObEGx
AkJPjWkERxqptWJFluDoPUJvHdz9cpvzcgtu/njfRmsPFVTflBcWTrbgM9sl
rw1KUkFnPedNrp4WvH1F4kZ7KSo8XHaPCy5owctXpZZMCf3n7ZSv1vmxBU9s
0JOoJvRh1MTc4I7oFmzc+FpU4gAV8rscJdNdW/AC4r9JJfTld53sypk7Lbgz
KiZnjNCf3dUTd44atODpEwJ1IoQ+Xc678/GbcgtmbEo1PE3o2XVySdprJVuw
29UHdeeUCT2XNDhxRaQFj02ZcKsT+lc9zPhg/2wzrkxWrFhP6GW9NW+b9g42
4yuKC1ojBFs+/+Fo19yMT7JiIjIJfe3yZ6MwtaQZr9aJT7Qm9DfJQZe6mN2M
E28GP9xC6PU3o8H6au+bsXXfX74igtONG+Z8ApuxtvoTYz1C3xe28b9ueNKM
u1M+PewjuF773LGNds349o8LF26qUKG37GWX0Y1mzHNxbrSJ4OljFe4J2s34
w8E7akeACpy5nDsYx5vxriumN0IIFtqHig/KNOMLR9OO9BEs8f6xifOWZrws
tKFVHFFBWfTriqJVzXhLqb3cVYLPBMzHc/1pwqGNcec8CDbgVlbXojXh524B
e2IIPs06+qO3owmvKqgMyCBYYfik3YPKJry7rUYq97/7lDbVlavymjDHv7DZ
NILXVJyOiklqwq+Dpaci/7tPoZyVVYhowt/WRm51JXgo8XzptxdNWFJowuUC
wU1hl68aPmzCB25p8G4iuMhLb3zKogmLMMq+tRHr//jg2jMv3SbckfYq77/7
lSiLGxs3qzfhvS3NP2QJ9tI1/ZhxqAlb51TLVhH2uad+C6ntbsLJn7LI+gQb
K1q1tW9ows+cqm1+EPY9J2FrbcNJrD/ZTP8SwRJcD8PC+htxbe+t8v/8tZ7p
sm9fUyPW4fDTtCP8+W/QvagQN2LX0g8cnwh/d5R50UbeNWKtNg+BXUQ8lJN9
Hj8KbMQzF5VuaRyhQnaC/4Z1TxsxJ678bUzEk69n2Imjxo2YrVmYeZeIP+f7
UU1154n+b873mSpSwcL8raXZyUace3njOS0iXk+eSgzy29aIT7X8qVog4ruf
+071V2oDFn6u7FNL5Ef+sP3sUFgD5nR7EWguTYWwCuftAg8aMMdv0bZJIp80
X7y8Z6LQgO/qhO0YIPIvkyt5M3dWPW4P1604LkYFn6HMUwcC6vFN/bnOB9uJ
/C//ZHvVth63fc5WiN9KBWGvbyWpMvVYR72z4IcoFdxWjlhdSKnDf4+/0y4Q
pILu4ESo88s6/PWPVU7kWqK+lLEK31vWYUOpkVu311Ch7zn3hlmJOvzc/kzZ
IA8VNDj35EfG1eIKLn+nS0sU2LDCYnX/m+/4n6r52sVRCvwOLT+t4v4dh2ml
V50f/u8+ec+z6BvfcUzA4t2IAQoEaI/M6e38jllS9k6rflFgVdSd4ZoPNXjE
XeqTUxMFOORsMSW7Gud4OGrYf6ZAb0nd4vqQauxfyHNOnEqBIt0Dh+3vV+Pd
jM2XqnMo4O42lbFPuRo3bO2wXkyjwHzFvejYr1X4oHXgWtpbCkwZOTn5fKvE
747FZw89Ier/VHvOcHIlbvbVKphzo0D688MTaqRKPP/uLJ3DmQLWKfPmS1qV
+B4HNYtlR3wPZt0uOzZ9w3nhvtJWxhTo8X2636i7Aqscqv/uepwCtZ99BuRm
ynArr5ajziQZKvJ7cuYby/AHkajuIhoZigoUn5VklWFpuhXfzkEy5OA+sSu2
ZdjmZ3Uu7iBDRNWRG060UtwufD3vESbDzU5aR0FPCS5VnSrqCiTD4FTwm9CI
Yjz01+H0TUni+z978uge3WK81W/PORsxMlTN0Ts+rS/G5HXDgXc3kSF9WVXk
p38RNthkOX1hNRmcBGcCd3oW4k0GR7xCJ3KBT07nRYb9V7z/dCv3ztxcOGC3
waFSMw97GEfZ3zmUCzKd9vIlq/PwoxPrzXNlckFKrW4mv/YT3jGi/mx2dy7s
2ujzMPPSJ3yZw/mioXAuiBYtuYUbULHYhRdZJcwc4BCgvzC/Q8YP5JwfTpBz
IN7w6eFlwSwc8Deeb0AmBxqo5O29297hmahTRddXZoP7WNDND/tiMYSmsl/N
ZoGUuF2cjXIM/norbPJqXxZ4+Evtmb8YjW2+l3vhL1mgYB6zf71nJH5PdvUZ
tskCGXEBZ+/mQOxwUJ+PVJcJHjbnZcYoGniDXlE0yTsDRHv/WQflxKArx28E
oGbi/NqgyKnMyEP+9xP8uy0SIU4hJXY5qQx5lKxGWvxvIXdBKsawqgztUjy1
rNoWDaWlqdF59DJU77KqXiM2GoZ0PkbZ7y9HXp9aFh8fjAbJ+5khvTnlaMit
3uur3htII1O8iwsqUET2xfqLiVGQq1hi97S5El1N9ve1vh4OpX9VbbtmK9H+
nnNVl/eGQ0t5qc1hkSqUHdVUf48ZBkzd8jtTV6vQ+MSxHIvAMFB+WGl281cV
EitI4tGrCoV8ap0+0KrRi20j+95ohhD68YJe9KoaRBMbX6W4JQS6TjdcmZOu
QT16Yzny48Hwt63xUpZtDUrgU9GyDA4GFXbLObHZGpTPNXRiW38QlCr/VFle
+o5wacrVdIVA2La2Xq94Ry1S0tP483A0AB4Oltx9CrVIfBo0vGICQCoo9c2y
Ry06XxPQHLE2AALoLuzllXXIweuyJfWfP9CK767FEnXIyvddeHmRP6hGmEh4
nK5D04dq0+56+ANTTVOH42Udev1571YKodeuvxXN5Fhdj1yN+KauH/ADiuOa
Cixdjz4/TFCz+Uvow7PLXR5a9WjzNGuXXa0vYNbIqhWv6tHPfLqysyOhN2t/
7izJqEfqHZfqQjR94X58/eFn9fUo7cGx+O87fUHy4qdbK9Y1IKFP4nMFHSTw
2JPmXnKwAZ3r7gjz+USCH4sxoc8uN6C43xqRkZEkUGgOTlN1bEDfmN6eM24k
8E95UbIitAHpdvmYxpmQYOSJa2cJuQHxpfzJ+ahJAtCznXrW2oCKhrwtNh0i
QZSMKY8aqwH5r3pfPyFGgj8eaQIr1jQiT+HGeHlBEkjeldhiurURuVVV02gc
JNC5GrunRKYRKeQCW5TlA0/VNsmLn2hETQrv7pSO+UC6bMiJZ9qN6LtVmdjY
kA/82MSv2W/UiI4s5BwN6/MBHi7vK6q2jei2kYNgcY8PKEwtG8c9bkSHK/8q
3O31gZs/Xa1XBDSijuZ7dtEDPuBfMfvQNLYRPei9Wq5F84HP2bbPSjIbkdzO
3fceTfvAcPSov3hxIxrj+TGxd9EHNrw0jXrW0Igsa1tmz/MR+3XsSujvbUSJ
vJHP6KIkuHtDL0t1uhGdaErsY+0j9q/ZkB/H0YSEuyHdVoUEFYfOfluxvgnJ
XuT6cU6PBDM7yppMxZsQbS0UetuRYMfqk79K5JuQ0Av65i2+JNBifaKJqzUh
Fo+cxFIyCVz6DjKf6TQhmxMmgXurSPDhe9pyv1kT6pE/GhnEIEHzJ4k1aveb
0ATHzdVygr4g82rTLs6wJrRceN1v2NgXDFxCZM0Sm5Ce/eMHdJIveJnzHy2l
NKHaOtewhU++0HOU49LztiZ0ot3LebOoHwSPjD7mFG1GCc3rfYQn/eCEC9VD
U7IZ6cUu/tGT8IeRVZ6eAUrNKOOVfqGQkT8ck91B2qLbjFaGjdf3NvjDwH3d
MIXgZsTvX51YVPkKFFaUpJmtaUFK+vcSBH8HQndIQEbKlhbUa3gjxmN7EHhL
GGVP7mtBN57KZzHVguDnmTmqm2YLSvZ+eRsFBsHzANmSkBctSM3Vi59XNhha
tr7pKF1uQStjDfOj3ULgScbtn3yCrWhVBP/lqg8hIAVKvy7saEXZPBI2qCkE
3M0aB36eaEUfq9rrV+0LBYlUnskZ11bEaazjWNYVCg+U73PtZrYiTdO0EmHt
cBC5rC3vSWtDL8OZOX3aUaAgI2Yt9KcNyTSdfb37eRRc4J6JT1jVjj4qOCh6
5UWBz5dI4XLpdjTmbZL+etdr+Cs+OMdl246OB4t7s/68hqEZ1yLv3+0oJDji
q096NJDDkrV8FzpQh987p+1b38HlTk7LYP6faC5Lma9+KR76/8Xbb2f8QmmB
egEP96bCe56V6af//EID3oKxPiqpYCxgTrPl60HJLRFBwXqp0L19t2mRZA/a
/7Twp5dnKrSfSNC5ad6DKjVPK0z1pEKtW4JSXHcP4l/9/Gt5aBp8ZicsSjT0
IrW3lyN5WB9B07n51MaffcgzirumPCQTTMW4H18c6EOLqzUcAlMywa3y8Ccf
Rh8yLPXlOFeUCR9FY6QWF/pQgxlnfAA9EwQ+317bt7UfxaVtUNWFLGib/9ue
eqMfPd6p+rtsNAvM3PZan+zvR7NRVo608Gx4tOt6ghO9H3kztDSL3mVDWI1/
d9bvfmS4Qe6gX2o2VGyZubCLcwAZFf/curowG6S+Fhzi3T2A4gPKM6IHs2Fq
8fJSo8UA+tGFDvDJ5YD7Y/cgC9oAehJKaekqyoHWeYOKddNEf68ex9lvOSDz
QGmhYG4A/VqKT+BsyIGf1pPmIryDiOU2kczbmwNHDEwOf9sziL6bmhd9/JcD
TAX1nr3mg6jZSFLb4EQu2NDW7B/7NYgk5fqv78nJhVJzmknk8CB6wE/qlPyc
C1t6y8NPTQyighMrzcSKc6Gq7fFy9N9BZHR3L4lVmwuSZVPN2luHkFyAXZES
LRcGYlpcMw2G0C7PFh/O7WS4fiW68l7LEJL2beukPCXDmKObaFnXEKLxtLgI
eJPBPeTabeGhIVTId0nwhj8ZYptEefOYQ6jLs1rwRxQZ+i+GafwVGUZbTUyn
tXLIcEf7VYW3wTCSFSpv29xHhj82d0U6TYbRJ7Xja0uGyeDrp3Vrn9UwuqYW
9s9ojDgv1azirnUdRopWVRz32WSY0vRWXx89jHqsB8RF+SngdPppWfSvYbR3
w8uhE0oU4L1lLDQxPIyiE66LHzhGgSivk+Yqk8PIoKZvQAgokF+2yNn/bxid
lygcLdCkwJKqi5rkzhHU5m6S6GVIAS+VeyXZZiOIEcp/k0acR0WML63ntBlB
L4d4vXd6UiDpsZzplfsjyKuCtfL8SwpUFUxwsD1HUGruyYXngRTgP26Njn8Y
QeTcAySzdxQIPWxeXDE6ggaX/AUmCyhgJj2+2ndqBImq1xXJYQoobH+of2Fu
BLnnrNx9u4wCzZwvJ9p5RhH7pwFHXjUF1tWnbaXtGUXux9f0/myjQB8+dDtd
dhStbz++XN1JgSxyQa6D0ih6NLriW2YXBS68rj/7R30UUThWq17rp4C/xYzz
aotRlHzOqlR+nAJGVx+V1duMoq0bH4/XTVJA5hyXYOj9UbSkLp9z8zcFauQ2
Jm31HEUd2uNcFmwK8C0ebd0fP4quiPFkTy0T9gl+dvBi3yjaUKuysH49oU+8
VrsL0UaRpJTdIV4hKux2Dq3smBpFxkpRs7+FqVBq9MHYZHkUHdXN50rZRAUO
qWr/eztoaLfrywsRhD5q3KLTqSRJQ7YXqQmHxanwbm3X7gVZGtrClnWp30UF
ldnx/OcnaUhnZ1h0N6GvHheto4caEe2NnlPdCH2mnfNa0cCChmJPyE5W7qfC
tsRdHtvu0lD4zr53qw9QoYCkKPrhEQ1V/EuxcSD0nb97oZmVJw0ZlTt6hcpT
wdBeI1PWj4ZSJdKF0hWosKBrcPrTGxp6t1U4tJDQizVn+oPc4mlId7/E80+E
nnx9zLpbJY1G7N9yOFGZCkd2ut+v/EJDHz1e8JgRepRPiLvYr4SGrEocyg4S
erWDO2D1pWoaEqenzzAJdhp7F9fZSUOL2x4m3SD0bmfc6dmHfTT01Shu9TLB
xwzG1IVoNHRhjZ9mBKGP3woER2RP0VCC9+DN3YR+XipXpp2foyHpB6aXkgg2
ftR9dOwfDdEw3ixG6G8s/9zPh4eO3ONKv74ieBdt7689AnQkEyKrPEOwV2zd
gTIROhrXr/PR/u/9hO59D5PtdOSw6Eh+S7Dmms3NSxJ0JNnCpA4QnFZStDt6
Px2ddz0QtANRgd/F4uERRTqaaORQu0Sw3YHVlW3H6YjGpfPdmeDGoaxN90/R
Eevl2v3h/91fROtZr9Oio4/CEhYpBIdeXvyaoUNHHhl+9/97P8LkjVurdZ2O
at7C9f/ej+gXadykmdJRyQO06QPBnx+MZ7+woqPngmEZgQRvkQnh3H2PjngD
T2/57/2Ie/9hXexCR7I3bhn/936kJ/LXhxsedJQis8ptA8Hogufcwks64mdq
2f73Hiaea9/ZqEA6yp87f8SfYK6v9W+UIulosFix6yjBlvcejDfHEvNtl9H/
Rdirau8WFYckOrq4zzTVieB9PcWBazPpqOgUfxs3wb5ht/rTqIQ9hW//8CX8
MX5uzSHNQjp675/ziZvg7Dz99ue1dPQ2TG6pm/DvBru/e3e20pGK9ZLlUYIf
SMS7FnbR0V+HqTS/Y1Q4HDyxbZ5BR3KZmaX/3YdFnQm1C5+ho623UORpIr4W
lo5ghQU6mjz/9Iz9YSoUWXuZ265ioN0VlScSifjcKS5NXb2egVasxc+ziPh9
3tHAk7KJgcL/qCVlH6LCafWtaQN7GcgcOHzCiPiv3Z47fVWDgWItJb4NEPlz
oPWqGus8A9XWbuKLIfIryHcpNESPgS78u7j/vDQVrsxpHq6zYCDTtWd2BO6l
ws/G3sdqngy0f29JwWsif0+8fNHQ68tAhzXX7Vm5kwqxJ2XEH4cwEK3r40Oz
HVQwS3Mqz4tjoDW68i2cW6lA91y7RhYzkLbJo6gaon549VCd7auI9Zf+ef+F
qC87jxoP5TQy0Nnli81vBYn4mMwsVO5nIGn4QoE1RH0xuOSAOMdQs4Zf7NwK
Ktwgz3c/Xz2GXk3HCfkQ9Wp+bdzZig1jaM3ZzwX8SxSQK/u969zuMXTgMmfO
zBwF3sqGtl1RHyPO784X5CcocNjnuFqENjHe8fJAcwZRjwcGMzt1x9B1v9Ub
fEf/uw9R9LlxawyVl/n2kYn66sTZfuy29xiq+LCr042oz5c6Nr13qxpDcU2N
vR35FBiTL+EvbBxDG89EbriYRwFvfyvX5c4x1Pi+6EM+mQKFqvk6XvQxdG+O
l22XTgHpdEOiYowjd5GVT7RjKMD1LNY6Tnscqby7Ar/cKfBZWkKpqnEc6b8w
j7t9iAIhBk4xjzvHUVsoR1/5AQrc9a7iPtQ3jvab79bcJE2BnQN322OmxhG/
1uZ3cTsp8PI11fm+wARaftCcpbKWAvp8Z/J3aE+giqzOzMQhMjCHreBh5QS6
+nqm7RDxPa8XKkiWbphAUvt7Qg2J732KqsC6vvYJVLj5a7urBxmMYnL7zo1M
IL3FPfOvH5ChTHfx2U7uSbR89B+XlREZQsr8y7+rTSLT7Z8UTkuTQT4u6+yu
okm0XdL6pgBxHlG/z1Xn/m0STbCezzjl5YLB6WuXOuonkQ3vCnprVi48oXNe
9e+dRB+dhITvvc+FWnl9CzbHFJITDZiSfpYLlqV/n9ScmkJiXutPpqJceDN4
luJYPYWECvhaWXk5wCnkGGhqPY1cV3b+EyFlQ9svad1HdtPojjnXG4Wn2ZCS
Mrgp3HEasZZlrTQeZsN5Fb34KrdptBi6VHjFNBuirI5Q5fym0cNyjiXuo9lw
AP/7ufRxGp2x/h4YU5cFhrZ+km8mptGSY4OMhksmUCoTC5sdfqMjIqWvVr77
CMeH1psm3JpBxtFPzG+WfYDply0WovazqM1AUH5DVwzscMnLZTvOonsBPNs/
JMeA9p1ojnanWRTVxktReRADKZrmb8OezKIy7eSNPmtjwHTVbMv6gFn0fFVC
lSd6C82+G07xZ8wi/VxN+JjyBqivLouvGJtF/YvRfCteRsLQYyX7vslZ9LKm
2aZCL5KoP5sLi2dm0aYwpYdpEpFgd6Hf4MnCLLpWZWvYVRoBkoL3ghZXMdFu
+asRfzkiICooaJklxUQ3x9KqnrwIA7fQhl8MSybiESiO31QQDPeGSzI/WTOR
fLyaMjskGO4cpjx9bsdE0zt0TspZB8PVrijxLU5M9IrWv7V4czAo7ja7dfYF
wZ77E9IeB4HMQ11lERITfZNrbcu7GgS7KjV4+/2ZCH1usj2qEATrbWRSXcKY
yLNqQ9DFpkCYzGWOJycwEf+rlY0H8gJgmGu08H4yMX+JNOP6/QDo1v8RAB+Z
aMut8/jjwQD4vlB4sCOXiRI7waQ78xWkqL18wFPKRCad9/xu5fvD+zDX080V
TLRDwiM83sMfIkdsNsZWM5FKzPlSTU1/8Pa99FmpiYmW4/1OM7v8wLx581+L
Pia6Y3rMvkzED65L8NcdHGKiOPvAp+o0X9Bx+hfzd5SJCgN1DzgV+ALaMghh
U0z0a/eTNQLWvnDkbts6k1km0verP/jilC/IFVX2y8wx0Wrpwtb6Hb6wwyzd
s+wfE+0PvHvzz08SiFBidQM5WeizP4cP/SsJ+HmC9xjysFBcydnEmlgScBl4
siVXs5Cvcl1IgicJFlMfVs6sZaHTyKDDzZrQ84u3o4rWs5Bz/Yow/SskYJy/
buUrwkKG8hbPTxD6v/+d9jH9zSykGCQ2IS9Dgs7fKmt2bWehIDVq6vEtJGg4
Jd89sZOF5ia/bzBeQ4Jv4bszvkiwUEfRGGfMPx8oGhV58kKKhU5sL2lYnPUB
6lG+i5f3s9BFg9nTj/+7H/FbENt+kIXebI3+sHvYBxJ/jU/TDrHQ5e3m76b7
fCBarreEcpjYj5ehznCPD4Q8awrxOM5CrwK9z3H2+gCppcxcG1got2uXx5l+
H/DY80lx0ymivSv1KoUYz8U5hXtIg4Xup7fEnxn3AfvqN+1Z51ioeTo1bpnp
A5ZbXyU/usBCDzKOc/9c9gFj26cuZ3QI+zTozrTwk0Cv+N5ZIX0WUo6U4GZs
JYH2eostvddYqHSDs94mWRKYUDtclm6w0FT9+QQRNRI8uKbVsdWMhTQUb5Of
XCOBz1KR0jFLYvwj5+O175PgbZxCmIE1C43VK7GcA0mQfTppxsmOhQpE6Qnz
GSQop2++HO7IQpRw4d3f6kkwLr9CoNmNhRJMBDfuFvUFjvYHd6efEPa7ZaL+
TsUXhN1oNQKeLMQ1LFivescXTpQ2vNTyYyHSymf1DSW+4K8Tu6IimoXGb6uo
dfv7wXv2epPBd4S/RLRMr5f7AeXNi6IViSz0wqiFO2nJD7oH7j5SSSfi4aX5
rPNDf9h//zgrr4CFkv1bfSpdXgESzbrSjllo4MhbifuFr0D3665cZjkLqQrN
XQhZGQDuK1fby9ex0B5/ai5HWADUhnbS0n6x0Ll3/748Lg+EvsPaZ6r7WUhG
tMCgeVUQMLuKP4wOs5AR17Znc/JBsE0i2UxikoXe+a+rHPIMgruUh90x/1go
vuXOQLNsMPC3bWgMEmOjBj8IjYgIAe2N5/OcTNko6K6mQN6HcFhOCA+9cIuN
5h1eqGm0hUOufI+9pBUb5TDLV3NwR8Dm8/ZS7Q5slKB49P2ERQSMeAa/VvJg
I2PO1jV+kpHw7HfbI2YsG+1sXt9ZmBUFn2qNkWM3G60TEQ1abo4GcU+Hatur
c4iibO5euiUOXPp5N3w2JJhUwTp/OA4a4d11TpM5ZKk4q9JxJQ48/taNRdyZ
Q9KZ6roD/nHQ91BGALvOIbU44wut/+Ig9s6Izoa3cyjcmL9gvj8etlww6v7U
N4eOatxRnktIBMf0WYkVw3PIinmO/LM4EWpW+9lq0eeQ0fcF6U9dieBa+eVf
7+85FKr1zUVX6AN0IlHxVSvnUY7M8RTp5x8g8lDzLcM988gQSTmJGSfBZLBV
5od986ie19bQ0TUJNKY55qZk59HmaQnxr2FJwE6X8/FSnkeTqS4tst+TQF/y
VVrGmXm0/xi3X9jhZMj0kpid0yL6q3DvC9VJBp7Br8fVLs0jQWP+fG/bZKC+
Y9S2G8yjtoNJp7QTkoH/3zMR8RvzaMdrEa4dRclgYbTZ2MZ0Hikz1M4MdSZD
QX52EvXWPLJX//w7djYZ/v97F3Sy7zjtvEAK/A+gX13Y
       "]]},
     Annotation[#, "Charting`Private`Tag$2409#2"]& ]}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0., 0.},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{
     FormBox[
      TagBox[
      "\"\\!\\(\\*TemplateBox[<|\\\"boxes\\\" -> FormBox[RowBox[{\\\" \\\", \
StyleBox[\\\"e\\\", \\\"TI\\\"]}], TraditionalForm], \\\"errors\\\" -> {}, \\\
\"input\\\" -> \\\"\\\\\\\\,e\\\", \\\"state\\\" -> \
\\\"Boxes\\\"|>,\\\"TeXAssistantTemplate\\\"]\\)\"", HoldForm], 
      TraditionalForm], None}, {
     FormBox[
      TagBox["\"Time (years)\"", HoldForm], TraditionalForm], None}},
  FrameStyle->Thickness[0.004],
  FrameTicks->{{{{0, 
       FormBox["0", TraditionalForm]}, {0.04, 
       FormBox["0.04`", TraditionalForm]}, {0.08, 
       FormBox["0.08`", TraditionalForm]}}, {}}, {{{-100000, 
       FormBox[
        RowBox[{"-", "100000"}], TraditionalForm]}, {-50000, 
       FormBox[
        RowBox[{"-", "50000"}], TraditionalForm]}, {0, 
       FormBox["0", TraditionalForm]}, {50000, 
       FormBox["50000", TraditionalForm]}, {100000, 
       FormBox["100000", TraditionalForm]}}, {}}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  LabelStyle->Directive[FontFamily -> "Times", FontSize -> 16],
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{-100000., 100000.}, {0., 0.1}},
  PlotRangeClipping->True,
  PlotRangePadding->{{None, None}, {None, None}},
  RotateLabel->False,
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.867736138155469*^9, {3.8677362162511597`*^9, 3.867736228375946*^9}, 
   3.867736292077386*^9, 3.867736656306547*^9, 3.890974906130584*^9},
 CellLabel->"Out[19]=",ExpressionUUID->"57a72667-b7fa-475f-a25a-d2973b4fd50c"]
}, Open  ]],

Cell["\<\
Define the labels for the plot of the variation in inclination.\
\>", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.8660041264449883`*^9, 3.8660041325640097`*^9}, {
  3.866029890140891*^9, 3.86602993667218*^9}, {3.866282127527829*^9, 
  3.866282190002166*^9}, {3.8662822302172823`*^9, 3.866282329322722*^9}, {
  3.866282369853121*^9, 3.866282394453143*^9}, {3.866282430858724*^9, 
  3.866282540539081*^9}, {3.8662825762398033`*^9, 3.866282618870384*^9}, {
  3.86628265396905*^9, 3.866282718243656*^9}, {3.866282806084441*^9, 
  3.8662828748935623`*^9}, {3.866282924052142*^9, 3.866283055107532*^9}, {
  3.866283118843275*^9, 3.866283158113332*^9}, {3.8663531452119713`*^9, 
  3.866353164696291*^9}, {3.866370479072535*^9, 3.8663705310635977`*^9}, {
  3.86637056805311*^9, 3.866371011248748*^9}, {3.8663711909578657`*^9, 
  3.866371259808771*^9}, {3.8663717081320677`*^9, 3.866371711221586*^9}, {
  3.866371747822688*^9, 3.866371752921891*^9}, {3.867735455341619*^9, 
  3.867735457306077*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"aad75dc3-bd4f-4fd6-b716-23e6f191b713"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"xlabel", "=", "\"\<Time (years)\>\""}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ylabel", "=", "\"\<\!\(\*TemplateBox[<|\"boxes\" -> FormBox[
RowBox[{\" \", 
StyleBox[\"I\", \"TI\"], \" \", 
RowBox[{\"(\", \"deg.\", \")\"}]}], TraditionalForm], \"errors\" -> {}, \
\"input\" -> \"\\\\,I\\\\,\\\\rm{ (deg.)}\", \"state\" -> \
\"Boxes\"|>,\"TeXAssistantTemplate\"]\)\>\""}], ";"}]}], "Input",
 CellChangeTimes->{{3.866019997647851*^9, 3.86601999950765*^9}, {
   3.866020049819096*^9, 3.866020058133103*^9}, {3.866363320190296*^9, 
   3.866363332819825*^9}, {3.8663634018648233`*^9, 3.866363457637225*^9}, {
   3.866363633695195*^9, 3.866363635415345*^9}, {3.867734127182289*^9, 
   3.867734137035391*^9}, {3.8677342222679768`*^9, 3.867734259047078*^9}, 
   3.8677355858029337`*^9},
 CellLabel->"In[20]:=",ExpressionUUID->"58703f0f-c7d6-4ae4-9258-cb5e072e054c"],

Cell["\<\
Do the same for the inclinations of Jupiter and Saturn.  This is Fig.7.1b.\
\>", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.867734071634342*^9, 3.867734080618845*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"1bbe19d2-36b5-4d98-9fd6-024baa06792f"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"ijcalc", "[", 
       RowBox[{"1", ",", "t"}], "]"}], "/", "Degree"}], ",", 
     RowBox[{
      RowBox[{"ijcalc", "[", 
       RowBox[{"2", ",", "t"}], "]"}], "/", "Degree"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", 
     RowBox[{"-", "100000"}], ",", "100000"}], "}"}], ",", "\n", "      ", 
   RowBox[{"PlotRange", "->", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "100000"}], ",", "100000"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "3"}], "}"}]}], "}"}]}], ",", 
   RowBox[{"Frame", "->", "True"}], ",", "\n", "      ", 
   RowBox[{"FrameStyle", "->", 
    RowBox[{"Thickness", "[", "0.004", "]"}]}], ",", "\n", "  ", 
   RowBox[{"FrameLabel", "->", 
    RowBox[{"{", 
     RowBox[{"xlabel", ",", "ylabel"}], "}"}]}], ",", 
   RowBox[{"RotateLabel", "->", "True"}], ",", "\n", "  ", 
   RowBox[{"AxesOrigin", "->", 
    RowBox[{"{", 
     RowBox[{"0", ",", "0"}], "}"}]}], ",", "\n", "  ", 
   RowBox[{"FrameTicks", "->", "\n", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", "1", ",", "2", ",", "3"}], "}"}], ",", "None"}], 
       "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "100000"}], ",", 
          RowBox[{"-", "50000"}], ",", "0", ",", "50000", ",", "100000"}], 
         "}"}], ",", "None"}], "}"}]}], "}"}]}], ",", "\n", "  ", 
   RowBox[{"LabelStyle", "\[Rule]", 
    RowBox[{"Directive", "[", 
     RowBox[{
      RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", 
      RowBox[{"FontSize", "\[Rule]", "16"}]}], "]"}]}], ",", "\n", "  ", 
   RowBox[{"PlotRangePadding", "\[Rule]", "None"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.867736393744656*^9, 3.867736393758762*^9}},
 CellLabel->"In[22]:=",ExpressionUUID->"dbb7aac0-5f86-48e3-881b-fc647fef8fca"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
      1.], LineBox[CompressedData["
1:eJwtm3k4VN8bwO1JSlEpUiqJtEiSSs5JpQ1JkigiRbaSXUQlSdJC0WbflX3L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       "]]},
     Annotation[#, "Charting`Private`Tag$2619#1"]& ], 
    TagBox[
     {RGBColor[0.880722, 0.611041, 0.142051], AbsoluteThickness[1.6], Opacity[
      1.], LineBox[CompressedData["
1:eJwtm3k4VN8bwJkZJSRZslRKRaJFknbnVZFQIUW2iCIVLUJSCKWSFkSWREkp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       "]]},
     Annotation[#, "Charting`Private`Tag$2619#2"]& ]}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0., 0.},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{
     FormBox[
      TagBox[
      "\"\\!\\(\\*TemplateBox[<|\\\"boxes\\\" -> FormBox[RowBox[{\\\" \\\", \
StyleBox[\\\"I\\\", \\\"TI\\\"], \\\" \\\", RowBox[{\\\"(\\\", \\\"deg.\\\", \
\\\")\\\"}]}], TraditionalForm], \\\"errors\\\" -> {}, \\\"input\\\" -> \
\\\"\\\\\\\\,I\\\\\\\\,\\\\\\\\rm{ (deg.)}\\\", \\\"state\\\" -> \
\\\"Boxes\\\"|>,\\\"TeXAssistantTemplate\\\"]\\)\"", HoldForm], 
      TraditionalForm], None}, {
     FormBox[
      TagBox["\"Time (years)\"", HoldForm], TraditionalForm], None}},
  FrameStyle->Thickness[0.004],
  FrameTicks->{{{{0, 
       FormBox["0", TraditionalForm]}, {1, 
       FormBox["1", TraditionalForm]}, {2, 
       FormBox["2", TraditionalForm]}, {3, 
       FormBox["3", TraditionalForm]}}, {}}, {{{-100000, 
       FormBox[
        RowBox[{"-", "100000"}], TraditionalForm]}, {-50000, 
       FormBox[
        RowBox[{"-", "50000"}], TraditionalForm]}, {0, 
       FormBox["0", TraditionalForm]}, {50000, 
       FormBox["50000", TraditionalForm]}, {100000, 
       FormBox["100000", TraditionalForm]}}, {}}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  LabelStyle->Directive[FontFamily -> "Times", FontSize -> 16],
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{-100000., 100000.}, {0., 3.}},
  PlotRangeClipping->True,
  PlotRangePadding->{{None, None}, {None, None}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.8113965341102858`*^9, 3.867736401397607*^9, 
  3.8677366566108913`*^9, 3.890974906310684*^9},
 CellLabel->"Out[22]=",ExpressionUUID->"05c3cc45-c989-46a6-afc0-748b12b4445f"]
}, Open  ]]
},
AutoGeneratedPackage->None,
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{1008, 663},
WindowMargins->{{88, Automatic}, {Automatic, 25}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
PrivateNotebookOptions->{"VersionedStylesheet"->{"Default.nb"[8.] -> False}},
ShowCellLabel->True,
ShowCellTags->False,
FrontEndVersion->"13.2 for Mac OS X x86 (64-bit) (November 18, 2022)",
StyleDefinitions->"Default.nb",
ExpressionUUID->"fe5261f5-9d1e-4b35-8fb6-2721071ef2da"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[558, 20, 439, 9, 53, "Text",ExpressionUUID->"e73af808-3ca8-448e-9019-d0da18204481"],
Cell[1000, 31, 96, 0, 67, "Section",ExpressionUUID->"68e7a372-2af0-423f-a89d-9014c82b299a"],
Cell[1099, 33, 308, 8, 49, "Text",ExpressionUUID->"9719ce43-3705-43bc-b327-9ad9c849b491"],
Cell[1410, 43, 6083, 210, 3738, "Input",ExpressionUUID->"ff4590b1-a226-44e0-963f-eb797962fbce"],
Cell[7496, 255, 406, 9, 76, "Text",ExpressionUUID->"e62469f6-7147-47e0-a9d0-edeb822093c2"],
Cell[CellGroupData[{
Cell[7927, 268, 461, 15, 228, "Input",ExpressionUUID->"857dc722-28aa-4132-99b2-fcba09c84fd1"],
Cell[8391, 285, 261, 5, 24, "Print",ExpressionUUID->"82390e79-5ff2-448a-8ff2-3c555d65be3a"],
Cell[8655, 292, 330, 8, 24, "Print",ExpressionUUID->"61c76648-2533-43c7-bdfd-30e156d7f3d7"],
Cell[8988, 302, 248, 5, 24, "Print",ExpressionUUID->"0629345a-f50b-43fd-afd7-ab5c49530d68"],
Cell[9239, 309, 265, 5, 24, "Print",ExpressionUUID->"da56a87f-61a7-47a6-8f27-5a8f63731ec2"],
Cell[9507, 316, 308, 7, 24, "Print",ExpressionUUID->"7cbd508e-616b-487e-b774-1acd76aeda1f"],
Cell[9818, 325, 249, 5, 24, "Print",ExpressionUUID->"f23f218b-c95e-4a5c-b5e0-de04255184c4"],
Cell[10070, 332, 279, 5, 24, "Print",ExpressionUUID->"8933496a-8b50-4d5d-9be7-160150567329"],
Cell[10352, 339, 323, 8, 24, "Print",ExpressionUUID->"74587877-51d1-49dd-a665-2d1d2eedc430"],
Cell[10678, 349, 249, 5, 24, "Print",ExpressionUUID->"f4659705-2030-4876-b118-d0ad6e26ed08"],
Cell[10930, 356, 264, 5, 24, "Print",ExpressionUUID->"a7d0a4c5-6437-4595-801c-57c8b42b375e"],
Cell[11197, 363, 264, 5, 24, "Print",ExpressionUUID->"c76d3b7d-734e-4df4-a682-41dcf4418433"],
Cell[11464, 370, 249, 5, 24, "Print",ExpressionUUID->"5ee1c969-e0d8-4a94-9aac-e64f6f1cf9ff"],
Cell[11716, 377, 262, 5, 24, "Print",ExpressionUUID->"e20f2e4a-1da5-40d5-b14c-840b09fcf8d3"],
Cell[11981, 384, 310, 7, 24, "Print",ExpressionUUID->"2cc7d777-8c14-40a1-ba50-d18a8d462058"],
Cell[12294, 393, 251, 5, 24, "Print",ExpressionUUID->"7b704843-4ec0-4e50-bb5e-bb788f299fe0"],
Cell[12548, 400, 273, 5, 24, "Print",ExpressionUUID->"61eecce6-45fa-409b-8804-2896c0ce5dc1"],
Cell[12824, 407, 328, 8, 24, "Print",ExpressionUUID->"e2e174d2-7d67-4146-b29d-e2af169f0732"],
Cell[13155, 417, 249, 5, 24, "Print",ExpressionUUID->"062630b7-bf68-40b9-a86a-f822dd3153cb"],
Cell[13407, 424, 262, 5, 24, "Print",ExpressionUUID->"4e35f010-4110-45e8-98ae-433051226a8e"],
Cell[13672, 431, 330, 8, 24, "Print",ExpressionUUID->"274e13a6-314d-46e1-8fe4-c91bc67cf8f3"],
Cell[14005, 441, 249, 5, 24, "Print",ExpressionUUID->"73f4ccb7-9ee7-4383-a169-004e4991a5c9"],
Cell[14257, 448, 278, 5, 24, "Print",ExpressionUUID->"24a3cb1b-970e-4401-a1a4-bd42386d58f6"],
Cell[14538, 455, 326, 8, 24, "Print",ExpressionUUID->"274ca06b-b1aa-46cf-bbbe-9badfcc68e4c"],
Cell[14867, 465, 251, 5, 24, "Print",ExpressionUUID->"61f61ef9-d48d-4653-84cf-d7c7f1ba25d4"],
Cell[15121, 472, 268, 5, 24, "Print",ExpressionUUID->"66438dfc-b1aa-479e-baac-177a00c88175"],
Cell[15392, 479, 820, 22, 40, "Print",ExpressionUUID->"1715508a-7e69-4b56-b7df-8ee1db55e441"],
Cell[16215, 503, 249, 5, 24, "Print",ExpressionUUID->"e0ac2eb4-7e99-4f12-a7f3-9ac6817be439"],
Cell[16467, 510, 266, 5, 24, "Print",ExpressionUUID->"7efeed8a-7a42-4201-8e66-67fa969776fe"],
Cell[16736, 517, 818, 22, 40, "Print",ExpressionUUID->"646911c6-189f-453c-a3fd-d19ea0b70e5d"],
Cell[17557, 541, 249, 5, 24, "Print",ExpressionUUID->"3587c037-d424-4e14-b1aa-5938d924acaf"],
Cell[17809, 548, 276, 5, 24, "Print",ExpressionUUID->"73c2c590-9d40-4e48-a78f-1b245df7a776"],
Cell[18088, 555, 330, 8, 24, "Print",ExpressionUUID->"32fda3e4-83de-4f48-88f0-c67bc425470e"],
Cell[18421, 565, 251, 5, 24, "Print",ExpressionUUID->"827e6bf0-8e4d-427c-9842-9edc7bb1a6ba"],
Cell[18675, 572, 263, 5, 24, "Print",ExpressionUUID->"6ad3867f-27e9-4d1e-b3b9-a1364322fb79"],
Cell[18941, 579, 831, 23, 40, "Print",ExpressionUUID->"8420584a-5813-4579-ac60-252a9ce2bc25"],
Cell[19775, 604, 251, 5, 24, "Print",ExpressionUUID->"bba5bae4-75e4-4c3a-a20b-e12e082cea2b"],
Cell[20029, 611, 279, 5, 24, "Print",ExpressionUUID->"7b6fa1b5-f061-4823-af26-f1baf6343f90"],
Cell[20311, 618, 327, 8, 24, "Print",ExpressionUUID->"ac88a49d-7fc7-4a6f-b04e-4284363006a1"],
Cell[20641, 628, 251, 5, 24, "Print",ExpressionUUID->"f2f8d0b3-d4ae-4d43-a5a9-5c9901c8f56b"],
Cell[20895, 635, 266, 5, 24, "Print",ExpressionUUID->"36b12b78-3df6-44de-8a74-598f5d46f8d5"],
Cell[21164, 642, 792, 21, 40, "Print",ExpressionUUID->"fb8be450-7145-450f-82d0-902991ace50c"],
Cell[21959, 665, 249, 5, 24, "Print",ExpressionUUID->"fb1e9223-1e66-4252-a133-d56a51e8069c"],
Cell[22211, 672, 268, 5, 24, "Print",ExpressionUUID->"5feca409-963f-4a2a-8a23-ef2d9a11453b"],
Cell[22482, 679, 329, 8, 24, "Print",ExpressionUUID->"eee557c3-6f97-4944-870b-2c4e8f3a7a5e"],
Cell[22814, 689, 251, 5, 24, "Print",ExpressionUUID->"8184dc6f-2a86-4306-80b1-7cdc447d4511"],
Cell[23068, 696, 266, 5, 24, "Print",ExpressionUUID->"a4e64e3b-ed5c-4e26-b2cc-b4746bf3cc14"],
Cell[23337, 703, 329, 8, 24, "Print",ExpressionUUID->"2be1b974-05ec-4628-9c4d-6e64e963c131"],
Cell[23669, 713, 248, 5, 24, "Print",ExpressionUUID->"09c59a2c-fc5a-4c4e-8bf3-7cb56e4c22ec"],
Cell[23920, 720, 268, 5, 24, "Print",ExpressionUUID->"bca4bc82-d315-4573-9b01-d6ac33ec1f3d"],
Cell[24191, 727, 328, 8, 24, "Print",ExpressionUUID->"c2ea444a-89e5-4e19-a37a-1baf2facf2a3"],
Cell[24522, 737, 251, 5, 24, "Print",ExpressionUUID->"2c53296f-a5b7-408a-8404-0e0eb8e7ef10"],
Cell[24776, 744, 265, 5, 24, "Print",ExpressionUUID->"55b8bdc8-dd28-43a3-814c-c18e7f490c4c"],
Cell[25044, 751, 360, 9, 24, "Print",ExpressionUUID->"ee05f6b4-ba9c-4664-82c2-891138c519f3"],
Cell[25407, 762, 249, 5, 24, "Print",ExpressionUUID->"69af9ed0-e610-4310-a9c2-6f69a272b8e9"],
Cell[25659, 769, 262, 5, 24, "Print",ExpressionUUID->"950ce144-a5c2-4c6f-896f-f7baf45968e2"],
Cell[25924, 776, 358, 9, 24, "Print",ExpressionUUID->"506ce087-4651-4fa6-a93f-e041946b1bc3"],
Cell[26285, 787, 251, 5, 24, "Print",ExpressionUUID->"a610bc02-db87-459b-8225-3af452f3e6f3"],
Cell[26539, 794, 261, 5, 24, "Print",ExpressionUUID->"ef85e237-a183-42a6-aa13-85a9bf7bf480"],
Cell[26803, 801, 324, 8, 24, "Print",ExpressionUUID->"da457e21-c6fe-4793-a20c-a0c8864e0fc0"],
Cell[27130, 811, 251, 5, 24, "Print",ExpressionUUID->"cdb9ef3f-d5b0-41ce-abbd-8ead1cf97cac"],
Cell[27384, 818, 275, 5, 24, "Print",ExpressionUUID->"fc94780b-1997-4383-8ec1-b8d94c596947"],
Cell[27662, 825, 840, 23, 40, "Print",ExpressionUUID->"89b5e781-26a2-4a9c-9605-ed41594a3a42"],
Cell[28505, 850, 249, 5, 24, "Print",ExpressionUUID->"5926c5c5-c733-427f-b16e-92c1b4f999aa"],
Cell[28757, 857, 273, 5, 24, "Print",ExpressionUUID->"7911b011-9ee1-4495-99cb-3a57561a8b41"],
Cell[29033, 864, 795, 21, 40, "Print",ExpressionUUID->"6ed52ae4-14aa-4613-973c-1e66e91af982"],
Cell[29831, 887, 249, 5, 24, "Print",ExpressionUUID->"d6377d1b-4ad4-47ff-ae2d-81cbd10df593"]
}, Open  ]],
Cell[30095, 895, 364, 10, 76, "Text",ExpressionUUID->"710d2172-b75e-4f02-bd8e-aa87cd85d443"],
Cell[CellGroupData[{
Cell[30484, 909, 126, 1, 30, "Input",ExpressionUUID->"ccba448d-6c91-443c-94cc-42c522113d36"],
Cell[30613, 912, 483, 9, 35, "Output",ExpressionUUID->"29366a73-0318-4d68-a41b-48c90dd87239"]
}, Open  ]],
Cell[CellGroupData[{
Cell[31133, 926, 152, 2, 30, "Input",ExpressionUUID->"4c549b27-c282-4bbc-8495-e53f03b7025a"],
Cell[31288, 930, 484, 9, 35, "Output",ExpressionUUID->"cd492e85-34c1-4a82-872d-e18ce9b86805"]
}, Open  ]],
Cell[31787, 942, 180, 3, 53, "Text",ExpressionUUID->"1e9a84a8-55da-4a7a-ae62-dbe7a5b67297"],
Cell[CellGroupData[{
Cell[31992, 949, 143, 2, 30, "Input",ExpressionUUID->"11ff5ff5-828d-4a60-8f2a-279fb77096cf"],
Cell[32138, 953, 237, 3, 34, "Output",ExpressionUUID->"3a34cb50-1056-4c03-9f7c-f81c097e5d78"]
}, Open  ]],
Cell[CellGroupData[{
Cell[32412, 961, 138, 2, 30, "Input",ExpressionUUID->"5bd21521-0d3b-44fa-8392-cc38b4d4456d"],
Cell[32553, 965, 236, 3, 34, "Output",ExpressionUUID->"4d066b08-0194-4590-9105-eba13493f36b"]
}, Open  ]],
Cell[32804, 971, 363, 10, 76, "Text",ExpressionUUID->"4144d348-7f5a-42a9-90f5-b2fb4a4b38ee"],
Cell[CellGroupData[{
Cell[33192, 985, 152, 2, 30, "Input",ExpressionUUID->"7be96441-07da-46ae-8c48-d1b95c822372"],
Cell[33347, 989, 553, 11, 35, "Output",ExpressionUUID->"f5ff6bc4-ecaa-4def-9f82-9613dba02f69"]
}, Open  ]],
Cell[CellGroupData[{
Cell[33937, 1005, 152, 2, 30, "Input",ExpressionUUID->"915be487-a204-4026-beea-cf2795772640"],
Cell[34092, 1009, 555, 11, 35, "Output",ExpressionUUID->"2e860df4-e23c-4184-86d7-12e26b9e6cb2"]
}, Open  ]],
Cell[34662, 1023, 180, 3, 53, "Text",ExpressionUUID->"fd03c01e-928d-4843-aa00-23d5b178a19e"],
Cell[CellGroupData[{
Cell[34867, 1030, 139, 2, 30, "Input",ExpressionUUID->"a35aed60-87fc-4c3a-a3df-fa3cbbe54ffd"],
Cell[35009, 1034, 235, 3, 34, "Output",ExpressionUUID->"11160cf1-bd95-4cd2-9adf-f59cff49d892"]
}, Open  ]],
Cell[CellGroupData[{
Cell[35281, 1042, 142, 2, 30, "Input",ExpressionUUID->"bfb5f243-9d30-4205-ae02-20b7bf1c1a1d"],
Cell[35426, 1046, 235, 3, 34, "Output",ExpressionUUID->"c653b09d-8a98-477a-adaa-b32aaf9b6e00"]
}, Open  ]],
Cell[35676, 1052, 999, 16, 53, "Text",ExpressionUUID->"90fe4803-20d1-48f0-b16d-f30542d276bb"],
Cell[36678, 1070, 767, 15, 53, "Input",ExpressionUUID->"b37d94ff-ebca-45f6-a9de-04d65a2aa42a"],
Cell[37448, 1087, 309, 7, 53, "Text",ExpressionUUID->"30238e04-ba0e-4c82-9b9f-17345e4ea5be"],
Cell[CellGroupData[{
Cell[37782, 1098, 2225, 56, 199, "Input",ExpressionUUID->"03fa848a-dfdd-4269-a4dd-81fe8968595b"],
Cell[40010, 1156, 38314, 653, 237, "Output",ExpressionUUID->"57a72667-b7fa-475f-a25a-d2973b4fd50c"]
}, Open  ]],
Cell[78339, 1812, 1096, 18, 53, "Text",ExpressionUUID->"aad75dc3-bd4f-4fd6-b716-23e6f191b713"],
Cell[79438, 1832, 908, 17, 53, "Input",ExpressionUUID->"58703f0f-c7d6-4ae4-9258-cb5e072e054c"],
Cell[80349, 1851, 274, 6, 53, "Text",ExpressionUUID->"1bbe19d2-36b5-4d98-9fd6-024baa06792f"],
Cell[CellGroupData[{
Cell[80648, 1861, 2001, 54, 199, "Input",ExpressionUUID->"dbb7aac0-5f86-48e3-881b-fc647fef8fca"],
Cell[82652, 1917, 45192, 765, 276, "Output",ExpressionUUID->"05c3cc45-c989-46a6-afc0-748b12b4445f"]
}, Open  ]]
}
]
*)

